/*     */ package com.jaspersoft.jasperserver.jaxrs.client.core;
/*     */ 
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.core.exceptions.JSClientWebException;
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.core.exceptions.handling.DefaultErrorHandler;
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.core.exceptions.handling.ErrorHandler;
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.core.operationresult.OperationResult;
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.core.operationresult.OperationResultFactory;
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.core.operationresult.OperationResultFactoryImpl;
/*     */ import com.jaspersoft.jasperserver.jaxrs.client.providers.CustomRepresentationTypeProvider;
/*     */ import com.sun.jersey.multipart.impl.MultiPartWriter;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map.Entry;
/*     */ import java.util.Set;
/*     */ import javax.ws.rs.client.Entity;
/*     */ import javax.ws.rs.client.Invocation.Builder;
/*     */ import javax.ws.rs.client.WebTarget;
/*     */ import javax.ws.rs.core.MultivaluedHashMap;
/*     */ import javax.ws.rs.core.MultivaluedMap;
/*     */ import javax.ws.rs.core.Response;
/*     */ import org.glassfish.jersey.jackson.JacksonFeature;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class JerseyRequest<ResponseType>
/*     */   implements RequestBuilder<ResponseType>
/*     */ {
/*     */   private static final int GET = 0;
/*     */   private static final int DELETE = 1;
/*     */   private static final int POST = 2;
/*     */   private static final int PUT = 3;
/*     */   private final OperationResultFactory operationResultFactory;
/*     */   private final Class<ResponseType> responseClass;
/*     */   private ErrorHandler errorHandler;
/*     */   private MultivaluedMap<String, String> headers;
/*     */   private WebTarget usersWebTarget;
/*     */   private String contentType;
/*     */   private String acceptType;
/*     */   
/*     */   protected JerseyRequest(SessionStorage sessionStorage, Class<ResponseType> responseClass)
/*     */   {
/*  63 */     this.operationResultFactory = new OperationResultFactoryImpl();
/*  64 */     this.responseClass = responseClass;
/*     */     
/*  66 */     RestClientConfiguration configuration = sessionStorage.getConfiguration();
/*     */     
/*  68 */     this.contentType = (configuration.getContentMimeType() == MimeType.JSON ? "application/json" : "application/xml");
/*  69 */     this.acceptType = (configuration.getAcceptMimeType() == MimeType.JSON ? "application/json" : "application/xml");
/*  70 */     this.headers = new MultivaluedHashMap();
/*  71 */     this.usersWebTarget = ((WebTarget)((WebTarget)((WebTarget)sessionStorage.getRootTarget().path("/rest_v2").register(CustomRepresentationTypeProvider.class)).register(JacksonFeature.class)).register(MultiPartWriter.class));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public static <T> JerseyRequest<T> buildRequest(SessionStorage sessionStorage, Class<T> responseClass, String[] path)
/*     */   {
/*  79 */     return buildRequest(sessionStorage, responseClass, path, null);
/*     */   }
/*     */   
/*     */   public static <T> JerseyRequest<T> buildRequest(SessionStorage sessionStorage, Class<T> responseClass, String[] path, ErrorHandler errorHandler) {
/*  83 */     JerseyRequest<T> request = new JerseyRequest(sessionStorage, responseClass);
/*  84 */     request.errorHandler = (errorHandler != null ? errorHandler : new DefaultErrorHandler());
/*  85 */     for (String pathElem : path) {
/*  86 */       request.setPath(pathElem);
/*     */     }
/*  88 */     return request;
/*     */   }
/*     */   
/*     */   public JerseyRequest<ResponseType> setPath(String path) {
/*  92 */     this.usersWebTarget = this.usersWebTarget.path(path);
/*  93 */     return this;
/*     */   }
/*     */   
/*     */   public OperationResult<ResponseType> get() throws JSClientWebException
/*     */   {
/*  98 */     Invocation.Builder request = buildRequest();
/*  99 */     return executeRequest(0, request);
/*     */   }
/*     */   
/*     */   public OperationResult<ResponseType> delete() throws JSClientWebException
/*     */   {
/* 104 */     Invocation.Builder request = buildRequest();
/* 105 */     return executeRequest(1, request);
/*     */   }
/*     */   
/*     */   public OperationResult<ResponseType> put(Object entity) throws JSClientWebException
/*     */   {
/* 110 */     Invocation.Builder request = buildRequest();
/* 111 */     return executeRequest(3, request, entity);
/*     */   }
/*     */   
/*     */   public OperationResult<ResponseType> post(Object entity) throws JSClientWebException
/*     */   {
/* 116 */     Invocation.Builder request = buildRequest();
/* 117 */     return executeRequest(2, request, entity);
/*     */   }
/*     */   
/*     */   private Invocation.Builder buildRequest() {
/* 121 */     Invocation.Builder request = this.usersWebTarget.request();
/* 122 */     if (this.acceptType != null) {
/* 123 */       request = request.accept(new String[] { this.acceptType });
/*     */     }
/* 125 */     addHeaders(request);
/* 126 */     return request;
/*     */   }
/*     */   
/*     */   private OperationResult<ResponseType> executeRequest(int httpMethod, Invocation.Builder request) {
/* 130 */     return executeRequest(httpMethod, request, null);
/*     */   }
/*     */   
/*     */   private OperationResult<ResponseType> executeRequest(int httpMethod, Invocation.Builder request, Object entity) {
/* 134 */     Response response = null;
/* 135 */     switch (httpMethod) {
/* 136 */     case 0:  response = request.get(); break;
/* 137 */     case 1:  response = request.delete(); break;
/* 138 */     case 2:  response = request.post(Entity.entity(entity, this.contentType)); break;
/* 139 */     case 3:  response = request.put(Entity.entity(entity, this.contentType));
/*     */     }
/* 141 */     if ((response != null) && (response.getStatus() >= 400)) {
/* 142 */       this.errorHandler.handleError(response);
/*     */     }
/* 144 */     return this.operationResultFactory.getOperationResult(response, this.responseClass);
/*     */   }
/*     */   
/*     */   private void addHeaders(Invocation.Builder request) {
/* 148 */     for (Iterator i$ = this.headers.entrySet().iterator(); i$.hasNext();) { header = (Map.Entry)i$.next();
/* 149 */       for (String value : (List)header.getValue()) {
/* 150 */         request = request.header((String)header.getKey(), value);
/*     */       }
/*     */     }
/*     */     Map.Entry<String, List<String>> header;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> addParam(String name, String... values) {
/* 157 */     this.usersWebTarget = this.usersWebTarget.queryParam(name, values);
/* 158 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> addParams(MultivaluedMap<String, String> params)
/*     */   {
/* 163 */     for (Map.Entry<String, List<String>> entry : params.entrySet()) {
/* 164 */       this.usersWebTarget = this.usersWebTarget.queryParam((String)entry.getKey(), ((List)entry.getValue()).toArray());
/*     */     }
/* 166 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> addMatrixParam(String name, String... values)
/*     */   {
/* 171 */     this.usersWebTarget = this.usersWebTarget.matrixParam(name, values);
/* 172 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> addMatrixParams(MultivaluedMap<String, String> params)
/*     */   {
/* 177 */     for (Map.Entry<String, List<String>> entry : params.entrySet()) {
/* 178 */       this.usersWebTarget = this.usersWebTarget.matrixParam((String)entry.getKey(), ((List)entry.getValue()).toArray());
/*     */     }
/* 180 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> setContentType(String contentType)
/*     */   {
/* 185 */     this.contentType = contentType;
/* 186 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> setAccept(String acceptMime)
/*     */   {
/* 191 */     this.acceptType = acceptMime;
/* 192 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> addHeader(String name, String... values)
/*     */   {
/* 197 */     this.headers.addAll(name, values);
/* 198 */     return this;
/*     */   }
/*     */   
/*     */   public RequestBuilder<ResponseType> setHeaders(MultivaluedMap<String, String> headers) {
/* 202 */     this.headers = headers;
/* 203 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public OperationResultFactory getOperationResultFactory()
/*     */   {
/* 211 */     return this.operationResultFactory;
/*     */   }
/*     */   
/*     */   public Class<ResponseType> getResponseClass() {
/* 215 */     return this.responseClass;
/*     */   }
/*     */   
/*     */   public ErrorHandler getErrorHandler() {
/* 219 */     return this.errorHandler;
/*     */   }
/*     */   
/*     */   public MultivaluedMap<String, String> getHeaders() {
/* 223 */     return this.headers;
/*     */   }
/*     */   
/*     */   public WebTarget getUsersWebTarget() {
/* 227 */     return this.usersWebTarget;
/*     */   }
/*     */   
/*     */   public String getContentType() {
/* 231 */     return this.contentType;
/*     */   }
/*     */   
/*     */   public String getAcceptType() {
/* 235 */     return this.acceptType;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\jrs-rest-java-client-6.0.3-ALPHA.jar!\com\jaspersoft\jasperserver\jaxrs\client\core\JerseyRequest.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */