/*     */ package com.jaspersoft.jasperserver.jaxrs.client.core;
/*     */ 
/*     */ import java.io.InputStream;
/*     */ import java.security.cert.CertificateException;
/*     */ import java.security.cert.X509Certificate;
/*     */ import java.util.Properties;
/*     */ import java.util.regex.Matcher;
/*     */ import java.util.regex.Pattern;
/*     */ import javax.net.ssl.TrustManager;
/*     */ import javax.net.ssl.X509TrustManager;
/*     */ import org.apache.commons.logging.Log;
/*     */ import org.apache.commons.logging.LogFactory;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class RestClientConfiguration
/*     */ {
/*  38 */   private static final Log log = LogFactory.getLog(RestClientConfiguration.class);
/*  39 */   private static final Pattern URL_PATTERN = Pattern.compile("\\b(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]");
/*     */   
/*     */   private String jasperReportsServerUrl;
/*  42 */   private MimeType contentMimeType = MimeType.JSON;
/*  43 */   private MimeType acceptMimeType = MimeType.JSON;
/*  44 */   private JRSVersion jrsVersion = JRSVersion.v5_5_0;
/*     */   private TrustManager[] trustManagers;
/*     */   private Integer connectionTimeout;
/*     */   private Integer readTimeout;
/*     */   
/*     */   public RestClientConfiguration(String jasperReportsServerUrl) {
/*  50 */     this();
/*  51 */     setJasperReportsServerUrl(jasperReportsServerUrl);
/*     */   }
/*     */   
/*     */   public RestClientConfiguration() {
/*  55 */     this.trustManagers = new TrustManager[] { new X509TrustManager()
/*     */     {
/*     */       public void checkClientTrusted(X509Certificate[] x509Certificates, String s)
/*     */         throws CertificateException
/*     */       {}
/*     */       
/*     */       public X509Certificate[] getAcceptedIssuers()
/*     */       {
/*  63 */         return null;
/*     */       }
/*     */       
/*     */ 
/*     */       public void checkServerTrusted(X509Certificate[] certs, String authType) {}
/*     */     } };
/*     */   }
/*     */   
/*     */   public String getJasperReportsServerUrl()
/*     */   {
/*  73 */     return this.jasperReportsServerUrl;
/*     */   }
/*     */   
/*     */   public void setJasperReportsServerUrl(String jasperReportsServerUrl) {
/*  77 */     Matcher matcher = URL_PATTERN.matcher(jasperReportsServerUrl);
/*  78 */     if (!matcher.matches())
/*  79 */       throw new IllegalArgumentException("Given parameter is not a URL");
/*  80 */     this.jasperReportsServerUrl = jasperReportsServerUrl;
/*     */   }
/*     */   
/*     */   public MimeType getContentMimeType() {
/*  84 */     return this.contentMimeType;
/*     */   }
/*     */   
/*     */   public void setContentMimeType(MimeType contentMimeType) {
/*  88 */     this.contentMimeType = contentMimeType;
/*     */   }
/*     */   
/*     */   public MimeType getAcceptMimeType() {
/*  92 */     return this.acceptMimeType;
/*     */   }
/*     */   
/*     */   public void setAcceptMimeType(MimeType acceptMimeType) {
/*  96 */     this.acceptMimeType = acceptMimeType;
/*     */   }
/*     */   
/*     */   public JRSVersion getJrsVersion() {
/* 100 */     return this.jrsVersion;
/*     */   }
/*     */   
/*     */   public void setJrsVersion(JRSVersion jrsVersion) {
/* 104 */     this.jrsVersion = jrsVersion;
/*     */   }
/*     */   
/*     */   public TrustManager[] getTrustManagers() {
/* 108 */     return this.trustManagers;
/*     */   }
/*     */   
/*     */   public void setTrustManagers(TrustManager[] trustManagers) {
/* 112 */     this.trustManagers = trustManagers;
/*     */   }
/*     */   
/*     */   public Integer getConnectionTimeout() {
/* 116 */     return this.connectionTimeout;
/*     */   }
/*     */   
/*     */   public void setConnectionTimeout(Integer connectionTimeout) {
/* 120 */     this.connectionTimeout = connectionTimeout;
/*     */   }
/*     */   
/*     */   public Integer getReadTimeout() {
/* 124 */     return this.readTimeout;
/*     */   }
/*     */   
/*     */   public void setReadTimeout(Integer readTimeout) {
/* 128 */     this.readTimeout = readTimeout;
/*     */   }
/*     */   
/*     */   public static RestClientConfiguration loadConfiguration(String path) {
/* 132 */     Properties properties = loadProperties(path);
/*     */     
/* 134 */     RestClientConfiguration configuration = new RestClientConfiguration();
/* 135 */     configuration.setJasperReportsServerUrl(properties.getProperty("url"));
/*     */     
/* 137 */     String connectionTimeout = properties.getProperty("connectionTimeout");
/* 138 */     if ((connectionTimeout != null) && (!connectionTimeout.equals(""))) {
/* 139 */       configuration.setConnectionTimeout(Integer.valueOf(connectionTimeout));
/*     */     }
/* 141 */     String readTimeout = properties.getProperty("readTimeout");
/* 142 */     if ((readTimeout != null) && (!readTimeout.equals(""))) {
/* 143 */       configuration.setConnectionTimeout(Integer.valueOf(readTimeout));
/*     */     }
/*     */     try {
/* 146 */       configuration.setContentMimeType(MimeType.valueOf(properties.getProperty("contentMimeType")));
/*     */     } catch (Exception e) {
/* 148 */       log.info("There is no mime type for content type or it isn't supported.", e);
/*     */     }
/*     */     try
/*     */     {
/* 152 */       configuration.setAcceptMimeType(MimeType.valueOf(properties.getProperty("acceptMimeType")));
/*     */     } catch (Exception e) {
/* 154 */       log.info("There is no mime type for accept type or it isn't supported.", e);
/*     */     }
/*     */     
/* 157 */     return configuration;
/*     */   }
/*     */   
/*     */   private static Properties loadProperties(String path) {
/* 161 */     Properties properties = new Properties();
/*     */     try {
/* 163 */       InputStream is = RestClientConfiguration.class.getClassLoader().getResourceAsStream(path);
/* 164 */       properties.load(is);
/*     */     } catch (Exception e) {
/* 166 */       log.info("Error when loading properties file", e);
/*     */     }
/* 168 */     return properties;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\jrs-rest-java-client-6.0.3-ALPHA.jar!\com\jaspersoft\jasperserver\jaxrs\client\core\RestClientConfiguration.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */