/*     */ package com.netapp.asup.data.function.aggregation;
/*     */ 
/*     */ import com.netapp.asup.client.arma.data.ARMAObjectInstance;
/*     */ import com.netapp.asup.client.arma.data.ARMAObjectInstanceIterator;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import java.util.Arrays;
/*     */ import java.util.List;
/*     */ import java.util.Stack;
/*     */ import org.apache.avro.util.Utf8;
/*     */ 
/*     */ public class ARMAPathInstanceIterator
/*     */ {
/*  14 */   private static AsupLogger logger = AsupLogger.getLogger(ARMAPathInstanceIterator.class);
/*     */   
/*     */ 
/*  17 */   private ARMAObjectInstance currentInstance = null;
/*     */   private final Stack<StackObject> workingStack;
/*     */   private final List<String> objects;
/*     */   private int currentObjectIndex;
/*     */   private final int maxObjectIndex;
/*     */   
/*     */   private static class StackObject
/*     */   {
/*     */     private final ARMAObjectInstanceIterator iterator;
/*     */     private final ARMAObjectInstance instance;
/*     */     private final boolean hasMultipleInstances;
/*     */     private final String objectName;
/*     */     
/*     */     private StackObject(String objectName, ARMAObjectInstanceIterator iterator) {
/*  31 */       this.objectName = objectName;
/*  32 */       this.iterator = iterator;
/*  33 */       this.instance = null;
/*  34 */       this.hasMultipleInstances = true;
/*     */     }
/*     */     
/*     */     private StackObject(String objectName, ARMAObjectInstance instance) {
/*  38 */       this.objectName = objectName;
/*  39 */       this.iterator = null;
/*  40 */       this.instance = instance;
/*  41 */       this.hasMultipleInstances = false;
/*     */     }
/*     */     
/*     */     public String toString()
/*     */     {
/*  46 */       return this.objectName;
/*     */     }
/*     */   }
/*     */   
/*     */   public ARMAPathInstanceIterator(ARMAObjectInstance rootInstance, String[] objects) throws ARMAException
/*     */   {
/*  52 */     this.objects = Arrays.asList(objects);
/*  53 */     this.workingStack = new Stack();
/*  54 */     this.maxObjectIndex = this.objects.size();
/*  55 */     this.currentObjectIndex = 0;
/*  56 */     String objectName = (String)this.objects.get(this.currentObjectIndex);
/*  57 */     this.currentInstance = getNextInstance(objectName, rootInstance);
/*     */   }
/*     */   
/*     */   private ARMAObjectInstance getNextInstance(String objectName, ARMAObjectInstance instance) throws ARMAException
/*     */   {
/*  62 */     if (instance.isParent(objectName)) {
/*  63 */       ARMAObjectInstance parentInstance = instance.getParentInstance(objectName);
/*  64 */       if (parentInstance != null) {
/*  65 */         StackObject object = new StackObject(objectName, parentInstance, null);
/*  66 */         this.workingStack.push(object);
/*  67 */         this.currentObjectIndex += 1;
/*  68 */         return getNextInstance();
/*     */       }
/*  70 */       updateStackAndCurrentIndex();
/*  71 */       return null;
/*     */     }
/*  73 */     if (instance.isChild(objectName)) {
/*  74 */       ARMAObjectInstanceIterator iterator = instance.getChildInstances(objectName);
/*  75 */       StackObject object = new StackObject(objectName, iterator, null);
/*  76 */       this.workingStack.push(object);
/*  77 */       this.currentObjectIndex += 1;
/*  78 */       return getNextInstance();
/*     */     }
/*  80 */     throw new ARMAException(logger, objectName + ":" + instance.getKey().toString(), "Invalid path, The object :" + objectName + " is neither parent nor child to object :" + instance.getObjectName());
/*     */   }
/*     */   
/*     */   private ARMAObjectInstance getNextInstance() throws ARMAException
/*     */   {
/*  85 */     if (this.currentObjectIndex == this.maxObjectIndex) {
/*  86 */       StackObject stackObject = (StackObject)this.workingStack.peek();
/*  87 */       if (stackObject.hasMultipleInstances) {
/*  88 */         if (stackObject.iterator.hasNext()) {
/*  89 */           return stackObject.iterator.next();
/*     */         }
/*  91 */         this.workingStack.pop();
/*  92 */         this.currentObjectIndex -= 1;
/*  93 */         updateStackAndCurrentIndex();
/*  94 */         return null;
/*     */       }
/*     */       
/*  97 */       this.workingStack.pop();
/*  98 */       this.currentObjectIndex -= 1;
/*  99 */       updateStackAndCurrentIndex();
/* 100 */       return stackObject.instance;
/*     */     }
/*     */     
/* 103 */     if (this.workingStack.isEmpty()) {
/* 104 */       return null;
/*     */     }
/* 106 */     StackObject stackObject = (StackObject)this.workingStack.peek();
/* 107 */     String objectName = (String)this.objects.get(this.currentObjectIndex);
/* 108 */     if (stackObject.hasMultipleInstances) {
/* 109 */       if (stackObject.iterator.hasNext()) {
/* 110 */         ARMAObjectInstance instance = stackObject.iterator.next();
/* 111 */         return getNextInstance(objectName, instance);
/*     */       }
/*     */       
/* 114 */       this.workingStack.pop();
/* 115 */       this.currentObjectIndex -= 1;
/* 116 */       updateStackAndCurrentIndex();
/* 117 */       return null;
/*     */     }
/*     */     
/* 120 */     ARMAObjectInstance instance = stackObject.instance;
/* 121 */     return getNextInstance(objectName, instance);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   private void updateStackAndCurrentIndex()
/*     */   {
/* 128 */     while (!this.workingStack.isEmpty()) {
/* 129 */       StackObject peek = (StackObject)this.workingStack.peek();
/* 130 */       if (peek.hasMultipleInstances) {
/*     */         break;
/*     */       }
/* 133 */       this.workingStack.pop();
/* 134 */       this.currentObjectIndex -= 1;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public boolean hasNext()
/*     */     throws ARMAException
/*     */   {
/* 142 */     while ((this.currentInstance == null) && (!this.workingStack.isEmpty())) {
/* 143 */       this.currentInstance = getNextInstance();
/*     */     }
/* 145 */     if (this.currentInstance == null) {
/* 146 */       return false;
/*     */     }
/* 148 */     return true;
/*     */   }
/*     */   
/*     */   public ARMAObjectInstance next() throws ARMAException
/*     */   {
/* 153 */     while ((this.currentInstance == null) && (!this.workingStack.isEmpty())) {
/* 154 */       this.currentInstance = getNextInstance();
/*     */     }
/* 156 */     ARMAObjectInstance currentInstance = this.currentInstance;
/* 157 */     this.currentInstance = null;
/* 158 */     return currentInstance;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\function\aggregation\ARMAPathInstanceIterator.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */