/*     */ package com.netapp.asup.data.objects;
/*     */ 
/*     */ import com.netapp.asup.data.exception.ARMARemoteCallException;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.OutputStream;
/*     */ import java.lang.reflect.Constructor;
/*     */ import java.util.HashMap;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import org.apache.avro.generic.GenericData.Record;
/*     */ import org.apache.avro.generic.GenericDatumReader;
/*     */ import org.apache.avro.generic.GenericRecord;
/*     */ import org.apache.avro.io.BinaryDecoder;
/*     */ import org.apache.avro.io.BinaryEncoder;
/*     */ import org.apache.avro.io.DecoderFactory;
/*     */ import org.apache.avro.io.EncoderFactory;
/*     */ 
/*     */ public abstract class AvroTransmissionObject extends AvroGenericRecordObject
/*     */ {
/*  22 */   protected final Map<AvroField, AvroObject<?>> fieldDataMap = new HashMap();
/*     */   
/*     */   protected final List<? extends AvroField> fields;
/*  25 */   protected static final DecoderFactory decoderFactory = ;
/*     */   
/*  27 */   protected BinaryEncoder binaryEncoder = null;
/*     */   
/*  29 */   protected BinaryDecoder binaryDecoder = null;
/*     */   
/*     */   public GenericRecord getObject() throws IOException {
/*  32 */     for (AvroField field : this.fields) {
/*  33 */       AvroObject<?> fieldData = (AvroObject)this.fieldDataMap.get(field.getFieldType());
/*  34 */       if (null != fieldData) {
/*  35 */         ((GenericRecord)this.object).put(field.getTagName(), fieldData.getObject());
/*     */       }
/*     */     }
/*  38 */     return (GenericRecord)this.object;
/*     */   }
/*     */   
/*     */   public <T> AvroTransmissionObject(ARMASchema schema, List<? extends AvroField> fields, String id) {
/*  42 */     super(schema, id);
/*  43 */     this.object = new GenericData.Record(schema.getSchema());
/*  44 */     this.fields = fields;
/*     */   }
/*     */   
/*     */   public AvroTransmissionObject(ARMASchema schema, GenericRecord object, List<AvroField> fields, String id)
/*     */   {
/*  49 */     super(schema, object, id);
/*  50 */     this.fields = fields;
/*     */   }
/*     */   
/*     */   public <T extends AvroObject<?>> T getField(AvroField field)
/*     */   {
/*  55 */     T wrappedObject = (AvroObject)this.fieldDataMap.get(field);
/*     */     try {
/*  57 */       if (wrappedObject != null)
/*  58 */         return wrappedObject;
/*  59 */       if ((this.object != null) && (((GenericRecord)this.object).get(field.getTagName()) != null)) {
/*  60 */         wrappedObject = (AvroObject)field.getType().getConstructor(new Class[] { field.getObjectType(), String.class }).newInstance(new Object[] { ((GenericRecord)this.object).get(field.getTagName()), this.id });
/*  61 */         this.fieldDataMap.put(field, wrappedObject);
/*  62 */         return wrappedObject;
/*     */       }
/*  64 */       Constructor<? extends AvroObject<?>> constructor = field.getType().getConstructor(new Class[] { String.class });
/*  65 */       wrappedObject = (AvroObject)constructor.newInstance(new Object[] { this.id });
/*  66 */       this.fieldDataMap.put(field, wrappedObject);
/*  67 */       return wrappedObject;
/*     */     }
/*     */     catch (Exception e)
/*     */     {
/*  71 */       new ARMAException(logger, getId(), "Error in constructing object caused by:" + e.getMessage(), e);
/*  72 */       throw new RuntimeException("Error in constructing object for field :" + field.getType().getCanonicalName() + " , caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public static <E extends AvroObject<?>> E initialize(ARMASchema schema, String id) throws ARMARemoteCallException
/*     */   {
/*  78 */     switch (schema) {
/*     */     case IDENTIFIER: 
/*  80 */       String[] split = id.split("_");
/*  81 */       if (2 == split.length) {
/*  82 */         return Identifier.initialize(split[0], Boolean.valueOf(split[1]).booleanValue());
/*     */       }
/*  84 */       if (3 == split.length)
/*  85 */         return Identifier.initialize(split[0], split[1], Boolean.valueOf(split[2]).booleanValue());
/*  86 */       if (4 == split.length) {
/*  87 */         return Identifier.initialize(split[0], split[1], split[2], Boolean.valueOf(split[3]).booleanValue());
/*     */       }
/*  89 */       if (5 == split.length) {
/*  90 */         return Identifier.initialize(split[0], split[1], split[2], Boolean.valueOf(split[3]).booleanValue(), Boolean.TRUE.booleanValue());
/*     */       }
/*     */       
/*     */ 
/*  94 */       throw new ARMARemoteCallException(logger, id, "Failed To initializa identifier,Value:" + id);
/*     */     case REQUEST: 
/*  96 */       return Request.initialize(id); }
/*  97 */     throw new ARMARemoteCallException(logger, id, "Schema not supported :" + schema.toString());
/*     */   }
/*     */   
/*     */   public void write(OutputStream os)
/*     */     throws ARMARemoteCallException
/*     */   {
/* 103 */     this.binaryEncoder = encoderFactory.binaryEncoder(os, this.binaryEncoder);
/*     */     try {
/* 105 */       this.schema.getWriter().write(getObject(), this.binaryEncoder);
/* 106 */       this.binaryEncoder.flush();
/*     */     } catch (IOException e) {
/* 108 */       throw new ARMARemoteCallException(logger, getId(), "Failed in writing bytes caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void read(byte[] bytes) throws ARMARemoteCallException
/*     */   {
/* 114 */     this.binaryDecoder = decoderFactory.binaryDecoder(bytes, this.binaryDecoder);
/*     */     try {
/* 116 */       this.schema.getReader().read(this.object, this.binaryDecoder);
/*     */     } catch (IOException e) {
/* 118 */       throw new ARMARemoteCallException(logger, getId(), "Failed in reading bytes caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void read(InputStream is) throws ARMARemoteCallException {
/* 123 */     this.binaryDecoder = decoderFactory.binaryDecoder(is, this.binaryDecoder);
/*     */     try {
/* 125 */       this.schema.getReader().read(this.object, this.binaryDecoder);
/*     */     } catch (IOException e) {
/* 127 */       throw new ARMARemoteCallException(logger, getId(), "Failed in reading input stream caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\objects\AvroTransmissionObject.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */