/*     */ package com.netapp.asup.data.store;
/*     */ 
/*     */ import com.netapp.asup.adapter.Adapter;
/*     */ import com.netapp.asup.cache.LRU.AsupLRUCache;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.data.objects.ARMASchema;
/*     */ import com.netapp.asup.data.objects.FunctionRequest;
/*     */ import com.netapp.asup.data.objects.Identifier;
/*     */ import com.netapp.asup.data.objects.ObjectData;
/*     */ import com.netapp.asup.data.objects.ObjectRequest;
/*     */ import com.netapp.asup.data.objects.Objects;
/*     */ import com.netapp.asup.data.objects.ObjectsRequest;
/*     */ import com.netapp.asup.data.objects.OptionData;
/*     */ import com.netapp.asup.data.objects.Options;
/*     */ import com.netapp.asup.data.objects.Request;
/*     */ import com.netapp.asup.data.objects.Response;
/*     */ import com.netapp.asup.data.schema.SchemaHelper;
/*     */ import com.netapp.asup.exception.ARMADataStoreException;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import com.netapp.asup.exception.ARMAFunctionExecutionException;
/*     */ import com.netapp.asup.exception.ARMAMetaModelException;
/*     */ import com.netapp.asup.exception.AdapterException;
/*     */ import com.netapp.asup.filter.DataFilterProcessor;
/*     */ import com.netapp.asup.metamodel.MetaModel;
/*     */ import com.netapp.asup.metamodel.MetaModelFactory;
/*     */ import com.netapp.asup.metamodel.NodeObject;
/*     */ import java.io.IOException;
/*     */ import java.util.Collection;
/*     */ import java.util.HashMap;
/*     */ import java.util.HashSet;
/*     */ import java.util.Iterator;
/*     */ import java.util.Map;
/*     */ import java.util.Map.Entry;
/*     */ import java.util.Set;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.Schema.Field;
/*     */ import org.apache.avro.generic.GenericData.Array;
/*     */ import org.apache.avro.generic.GenericRecord;
/*     */ import org.apache.avro.util.Utf8;
/*     */ 
/*     */ public class DataStoreImpl implements DataStore
/*     */ {
/*     */   private static final String OPTION_GROUP_ID = "option_group_id";
/*     */   private static final String CONFIG = "config";
/*  45 */   private static final AsupLogger LOGGER = AsupLogger.getLogger(DataStoreImpl.class);
/*     */   
/*     */   private AsupLRUCache<String, Object> cache;
/*     */   
/*     */   private Adapter adapter;
/*     */   
/*     */   private MetaModelFactory metaModelprovider;
/*     */   
/*  53 */   private DataFilterProcessor filterProcessor = new DataFilterProcessor();
/*     */   
/*     */   public DataStoreImpl(Adapter adapter, AsupLRUCache<String, Object> cache, MetaModelFactory metaModelprovider, SchemaHelper schemaHelper) {
/*  56 */     this.cache = cache;
/*  57 */     this.adapter = adapter;
/*  58 */     this.metaModelprovider = metaModelprovider;
/*     */   }
/*     */   
/*     */   public NodeObject getMetaModel(String sysVersion, String asupType) throws ARMADataStoreException
/*     */   {
/*     */     try {
/*  64 */       return this.metaModelprovider.getMetaModel(sysVersion, asupType).getRoot();
/*     */     } catch (ARMAMetaModelException e) {
/*  66 */       throw new ARMADataStoreException(LOGGER, "Failed to get meta model for the system version:" + sysVersion, e);
/*     */     }
/*     */   }
/*     */   
/*     */   public Identifier getMetaData(Identifier identifier) throws ARMADataStoreException
/*     */   {
/*     */     try {
/*  73 */       return this.adapter.getMetaData(identifier);
/*     */     } catch (Exception e) {
/*  75 */       throw new ARMADataStoreException(LOGGER, "Failed to get meta Data", e);
/*     */     }
/*     */   }
/*     */   
/*     */   private Set<Utf8> getOptionGroupIds(ObjectData objectData) {
/*  80 */     Iterator<Map<Utf8, GenericRecord>> it = objectData.getSystemToGenericRecord().values().iterator();
/*  81 */     GenericRecord record = null;
/*  82 */     HashSet<Utf8> optionGroupIds = new HashSet();
/*  83 */     while (it.hasNext()) {
/*  84 */       Iterator<GenericRecord> insIt = ((Map)it.next()).values().iterator();
/*  85 */       while (insIt.hasNext()) {
/*  86 */         record = (GenericRecord)insIt.next();
/*  87 */         optionGroupIds.add((Utf8)((GenericRecord)record.get("config")).get("option_group_id"));
/*     */       }
/*     */     }
/*     */     
/*  91 */     return optionGroupIds;
/*     */   }
/*     */   
/*     */   private Response getAndMergeOptionsData(Request request, Response response, Set<Utf8> optionGroupIds) throws AdapterException, IOException
/*     */   {
/*  96 */     LOGGER.info(null, "option group id list : " + optionGroupIds);
/*  97 */     Identifier identifier = request.getIdentifier();
/*  98 */     Map<Utf8, OptionData> optionDataMap = new HashMap();
/*     */     
/* 100 */     OptionData optionData = null;
/* 101 */     Set<Utf8> missingOptionGroupIds = new HashSet();
/* 102 */     for (Utf8 optionGroupId : optionGroupIds)
/*     */     {
/* 104 */       if (optionGroupId != null) {
/* 105 */         optionData = (OptionData)this.cache.get(optionGroupId.toString());
/* 106 */         if (optionData == null)
/*     */         {
/* 108 */           missingOptionGroupIds.add(optionGroupId);
/*     */         }
/*     */         else
/*     */         {
/* 112 */           optionDataMap.put(optionGroupId, optionData);
/*     */         }
/*     */       }
/*     */     }
/*     */     
/* 117 */     if (missingOptionGroupIds.size() > 0) {
/* 118 */       GenericData.Array<Utf8> ogids = new GenericData.Array(optionGroupIds.size(), ARMASchema.IDENTIFIER.getSchema().getField("option_group_id").schema());
/*     */       
/* 120 */       for (Utf8 optionGroupId : missingOptionGroupIds) {
/* 121 */         ogids.add(optionGroupId);
/*     */       }
/*     */       
/* 124 */       identifier.setOptionGroupIds(ogids);
/*     */       
/* 126 */       Response responseData = this.adapter.getOptionData(request);
/*     */       
/*     */ 
/* 129 */       optionDataMap.putAll(responseData.getOptions().getOptionDataMap());
/*     */     }
/*     */     
/*     */ 
/* 133 */     if (optionDataMap.size() > 0) {
/* 134 */       response.getOptions().setOptions(optionDataMap);
/*     */     }
/* 136 */     return response;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Response getObject(Identifier identifier, String objectName, ObjectRequest objectReq)
/*     */     throws ARMADataStoreException
/*     */   {
/* 146 */     Utf8 encodedObjectName = new Utf8(objectName);
/* 147 */     Request request = Request.initialize(identifier);
/* 148 */     request.getRequestObject().addRequestObject(encodedObjectName, objectReq);
/*     */     
/*     */ 
/* 151 */     this.filterProcessor.addDependentObjects(request);
/*     */     
/* 153 */     ObjectData objectData = null;
/* 154 */     Response responseData = null;
/*     */     
/* 156 */     boolean isOptionSupported = false;
/*     */     try
/*     */     {
/* 159 */       isOptionSupported = objectReq.isOptionsAvailable();
/* 160 */       objectData = (ObjectData)this.cache.get(identifier.getHash() + objectName);
/* 161 */       if (null != objectData)
/*     */       {
/* 163 */         responseData = Response.defaultInitialize(identifier.getId());
/* 164 */         responseData.getObjects().putObjectData(objectData);
/* 165 */         if (isOptionSupported) {
/* 166 */           Set<Utf8> optionGroupIds = getOptionGroupIds(objectData);
/* 167 */           responseData = getAndMergeOptionsData(request, responseData, optionGroupIds);
/*     */ 
/*     */         }
/*     */         
/*     */ 
/*     */       }
/*     */       else
/*     */       {
/*     */ 
/* 176 */         responseData = this.adapter.getObjectData(request);
/*     */       }
/*     */       
/*     */ 
/*     */ 
/* 181 */       populateCacheAndApplyFilters(request, responseData);
/*     */     }
/*     */     catch (AdapterException e) {
/* 184 */       throw new ARMADataStoreException(LOGGER, identifier.getId(), "Exception caused in retreiving data for object :" + objectName + " caused by :" + e.getMessage(), e);
/*     */     }
/*     */     catch (IOException e) {
/* 187 */       throw new ARMADataStoreException(LOGGER, identifier.getId(), "Excetpion caused in retreiving data for object :" + objectName + " caused by :" + e.getMessage(), e);
/*     */     }
/*     */     
/*     */ 
/* 191 */     return responseData;
/*     */   }
/*     */   
/*     */   public Response getObject(Identifier identifier, String objectName, NodeObject parentNodeObject)
/*     */     throws ARMADataStoreException
/*     */   {
/* 197 */     Utf8 parentObjectName = new Utf8(parentNodeObject.getName().toUpperCase());
/* 198 */     Utf8 encodedObjectName = new Utf8(objectName);
/* 199 */     String objectNameStrUpper = objectName;
/*     */     
/* 201 */     Request request = Request.initialize(identifier);
/* 202 */     ObjectsRequest requestObject = request.getRequestObject();
/* 203 */     ObjectRequest objReq = ObjectRequest.initialize(identifier.getId(), objectNameStrUpper);
/* 204 */     ObjectRequest parentObjReq = ObjectRequest.initialize(identifier.getId(), parentObjectName.toString());
/*     */     
/* 206 */     requestObject.addRequestObject(encodedObjectName, objReq);
/* 207 */     requestObject.addRequestObject(parentObjectName, parentObjReq);
/*     */     
/*     */ 
/*     */ 
/*     */ 
/* 212 */     this.filterProcessor.addDependentObjects(request);
/*     */     
/* 214 */     Response responseData = null;
/* 215 */     ObjectData objectData = null;
/* 216 */     ObjectData parentObjectData = null;
/* 217 */     Map<Utf8, Map<Utf8, GenericData.Array<Utf8>>> indexData = null;
/*     */     try
/*     */     {
/* 220 */       objectData = (ObjectData)this.cache.get(identifier.getHash() + objectNameStrUpper);
/* 221 */       parentObjectData = (ObjectData)this.cache.get(identifier.getHash() + parentObjectName);
/* 222 */       if ((null != objectData) && (null != parentObjectData)) {
/* 223 */         indexData = (Map)objectData.getIndexMap().get(parentObjectName);
/*     */         
/* 225 */         responseData = Response.defaultInitialize(identifier.getId());
/* 226 */         responseData.getObjects().putObjectData(objectData);
/* 227 */         responseData.getObjects().putObjectData(parentObjectData);
/*     */       }
/*     */       else
/*     */       {
/* 231 */         responseData = this.adapter.getParentObjectData(request);
/* 232 */         objectData = responseData.getObjects().getObjectData(encodedObjectName);
/*     */       }
/*     */       
/* 235 */       if (null == indexData)
/*     */       {
/* 237 */         Map<Utf8, Map<Utf8, Map<Utf8, GenericData.Array<Utf8>>>> populateIndexesForParent = objectData.populateIndexesForParent(parentNodeObject);
/*     */         
/* 239 */         objectData.setIndex(populateIndexesForParent);
/*     */       }
/*     */       
/*     */ 
/* 243 */       populateCacheAndApplyFilters(request, responseData);
/*     */     }
/*     */     catch (AdapterException e) {
/* 246 */       throw new ARMADataStoreException(LOGGER, identifier.getId(), "Excetpion caused in retreiving data for object :" + objectName + " caused by :" + e.getMessage(), e);
/*     */     }
/*     */     catch (IOException e) {
/* 249 */       throw new ARMADataStoreException(LOGGER, identifier.getId(), "Excetpion caused in deserializing data for object :" + objectName + " caused by :" + e.getMessage(), e);
/*     */     }
/*     */     
/*     */     try
/*     */     {
/* 254 */       parentObjectData = responseData.getObjects().getObjectData(parentObjectName);
/*     */     } catch (IOException e1) {
/* 256 */       throw new ARMADataStoreException(LOGGER, identifier.getId(), "Excetpion caused in retreiving data for object :" + objectName + " caused by :" + e1.getMessage(), e1);
/*     */     }
/*     */     
/* 259 */     return responseData;
/*     */   }
/*     */   
/*     */ 
/*     */   public Response getData(Request request)
/*     */     throws ARMADataStoreException
/*     */   {
/* 266 */     this.filterProcessor.addDependentObjects(request);
/*     */     
/*     */ 
/* 269 */     Map<String, ObjectData> localResultData = getLocalObjectData(request.getIdentifier(), getObjectsToRequested(request));
/*     */     
/* 271 */     Map<String, OptionData> localOptionData = getLocalOptionsData(localResultData, getOptionsRequested(request));
/*     */     
/*     */ 
/*     */ 
/* 275 */     Response responseData = getAndMergeObjectData(localResultData, localOptionData, request);
/*     */     
/*     */     try
/*     */     {
/* 279 */       populateCacheAndApplyFilters(request, responseData);
/*     */     } catch (IOException e) {
/* 281 */       throw new ARMADataStoreException(LOGGER, request.getIdentifier().getId(), "Excetpion occured in retreiving data for object,Caused by:" + e.getMessage(), e);
/*     */     }
/*     */     
/* 284 */     executeFunctions(request, responseData);
/*     */     
/*     */ 
/* 287 */     return responseData;
/*     */   }
/*     */   
/*     */   private void executeFunctions(Request request, Response responseData) throws ARMADataStoreException {
/*     */     try {
/* 292 */       FunctionRequest functionRequest = request.getFunctionRequest();
/* 293 */       functionRequest.execute(request.getIdentifier(), responseData);
/*     */     }
/*     */     catch (ARMAFunctionExecutionException e) {
/* 296 */       throw new ARMADataStoreException(LOGGER, "Failed to execute the functions:" + e.getMessage(), e);
/*     */     } catch (ARMAException e) {
/* 298 */       throw new ARMADataStoreException(LOGGER, "Failed to execute the functions:" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   private void populateCacheAndApplyFilters(Request request, Response responseData) throws IOException, ARMADataStoreException {
/* 303 */     Objects responseObjects = responseData.getObjects();
/* 304 */     ObjectData objectData = null;
/* 305 */     Utf8 optionGroupId = null;
/* 306 */     OptionData optionData = null;
/*     */     
/*     */ 
/*     */ 
/* 310 */     for (Utf8 objectName : responseObjects.getObjectSet()) {
/* 311 */       objectData = responseObjects.getObjectData(objectName);
/* 312 */       this.cache.put(request.getIdentifier().getHash() + objectName.toString(), objectData);
/*     */     }
/*     */     
/*     */ 
/* 316 */     Map<Utf8, OptionData> optionMap = responseData.getOptions().getOptionDataMap();
/*     */     
/* 318 */     for (Map.Entry<Utf8, OptionData> entrySet : optionMap.entrySet()) {
/* 319 */       optionGroupId = (Utf8)entrySet.getKey();
/* 320 */       optionData = (OptionData)entrySet.getValue();
/* 321 */       if (optionGroupId != null) {
/* 322 */         this.cache.put(optionGroupId.toString(), optionData);
/*     */       }
/*     */     }
/*     */     
/* 326 */     this.filterProcessor.applyFilters(request, responseData);
/*     */   }
/*     */   
/*     */   private Response getAndMergeObjectData(Map<String, ObjectData> localResultData, Map<String, OptionData> localOptionData, Request request)
/*     */     throws ARMADataStoreException
/*     */   {
/* 332 */     String[] localObjectNames = new String[localResultData.size()];
/*     */     
/* 334 */     String[] localOptionGroupIds = new String[localOptionData.size()];
/*     */     
/* 336 */     int index = 0;
/* 337 */     ObjectData objectData = null;
/* 338 */     for (String objectName : localResultData.keySet())
/*     */     {
/* 340 */       objectData = (ObjectData)localResultData.get(objectName);
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 345 */       if (null != objectData) {
/* 346 */         localObjectNames[index] = objectName;
/* 347 */         index++;
/*     */       }
/*     */     }
/*     */     
/* 351 */     GenericData.Array<Utf8> groupIds = new GenericData.Array(localOptionGroupIds.length, ARMASchema.IDENTIFIER.getSchema().getField("option_group_id").schema());
/*     */     
/* 353 */     for (String optionGroupId : localOptionData.keySet()) {
/* 354 */       groupIds.add(new Utf8(optionGroupId));
/*     */     }
/*     */     
/*     */ 
/* 358 */     request.getIdentifier().setOptionGroupIds(groupIds);
/*     */     
/*     */ 
/* 361 */     ObjectsRequest requestObject = request.getRequestObject();
/* 362 */     Utf8 objectNameUtf8 = null;
/* 363 */     for (String localObjectName : localObjectNames) {
/* 364 */       objectNameUtf8 = new Utf8(localObjectName);
/*     */       
/*     */ 
/* 367 */       requestObject.updateRequestObjectAsCached(objectNameUtf8);
/*     */       
/* 369 */       request.removeDependentObject(objectNameUtf8);
/*     */     }
/*     */     
/* 372 */     Response response = null;
/* 373 */     if ((requestObject.getObjects().isEmpty()) && (request.getDependentObjects().isEmpty())) {
/* 374 */       response = Response.initialize(request.getId());
/*     */     } else {
/*     */       try {
/* 377 */         response = this.adapter.getData(request);
/*     */       } catch (AdapterException e) {
/* 379 */         throw new ARMADataStoreException(LOGGER, "Failed to get Data", e);
/*     */       }
/*     */     }
/*     */     
/* 383 */     Objects objects = response.getObjects();
/* 384 */     for (ObjectData cachedObjs : localResultData.values()) {
/* 385 */       objects.putObjectData(cachedObjs);
/*     */     }
/*     */     
/* 388 */     Options options = response.getOptions();
/*     */     
/* 390 */     for (Map.Entry<String, OptionData> optionEntry : localOptionData.entrySet()) {
/* 391 */       options.putOptionData(new Utf8((String)optionEntry.getKey()), (OptionData)optionEntry.getValue());
/*     */     }
/*     */     
/* 394 */     return response;
/*     */   }
/*     */   
/*     */   private Map<String, ObjectData> getLocalObjectData(Identifier identifier, Set<Utf8> reqObjs)
/*     */   {
/* 399 */     Map<String, ObjectData> localResultData = new HashMap();
/* 400 */     ObjectData cachedObjectData = null;
/* 401 */     String objName = null;
/* 402 */     for (Utf8 reqObj : reqObjs) {
/* 403 */       objName = reqObj.toString();
/* 404 */       cachedObjectData = (ObjectData)this.cache.get(identifier.getHash() + objName);
/* 405 */       if (null != cachedObjectData) {
/* 406 */         localResultData.put(objName, cachedObjectData);
/*     */       }
/*     */     }
/* 409 */     return localResultData;
/*     */   }
/*     */   
/*     */   private Map<String, OptionData> getLocalOptionsData(Map<String, ObjectData> objectDataMap, Set<Utf8> optionsObjects)
/*     */   {
/* 414 */     Map<String, OptionData> localOptionData = new HashMap();
/*     */     
/* 416 */     String objName = null;
/* 417 */     ObjectData objectData = null;
/*     */     
/* 419 */     OptionData optionData = null;
/* 420 */     String ogIdStr = null;
/* 421 */     for (Utf8 optionObj : optionsObjects) {
/* 422 */       objName = optionObj.toString();
/* 423 */       objectData = (ObjectData)objectDataMap.get(objName);
/* 424 */       if (objectData != null) {
/* 425 */         Set<Utf8> optionGroupIds = getOptionGroupIds(objectData);
/* 426 */         for (Utf8 optionGroupId : optionGroupIds) {
/* 427 */           if (optionGroupId != null) {
/* 428 */             ogIdStr = optionGroupId.toString();
/* 429 */             optionData = (OptionData)this.cache.get(ogIdStr);
/* 430 */             if (optionData != null) {
/* 431 */               localOptionData.put(optionGroupId.toString(), optionData);
/*     */             }
/*     */           }
/*     */         }
/*     */       }
/*     */     }
/*     */     
/*     */ 
/* 439 */     return localOptionData;
/*     */   }
/*     */   
/*     */ 
/*     */   private Set<Utf8> getObjectsToRequested(Request request)
/*     */   {
/* 445 */     Set<Utf8> reqObjects = new HashSet();
/* 446 */     reqObjects.addAll(request.getRequestObject().getObjects());
/* 447 */     reqObjects.addAll(request.getDependentObjects());
/* 448 */     return reqObjects;
/*     */   }
/*     */   
/*     */   private Set<Utf8> getOptionsRequested(Request request)
/*     */   {
/* 453 */     Set<Utf8> reqObjects = new HashSet();
/* 454 */     reqObjects.addAll(request.getRequestObject().getOptions());
/*     */     
/* 456 */     return reqObjects;
/*     */   }
/*     */   
/*     */   public void cacheObjects(Identifier identifier, Objects objects)
/*     */     throws ARMADataStoreException
/*     */   {
/*     */     try
/*     */     {
/* 464 */       for (Utf8 objectName : objects.getObjectSet()) {
/* 465 */         this.cache.put(identifier.getHash() + objectName.toString(), objects.getObjectData(objectName));
/*     */       }
/*     */     } catch (IOException e) {
/* 468 */       throw new ARMADataStoreException(LOGGER, identifier.getHash(), "Failed to cache objects from the result data:" + objects, e);
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\store\DataStoreImpl.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */