/*     */ package com.netapp.asupdata.client.ARMA;
/*     */ 
/*     */ import com.netapp.asup.client.arma.ARMAObject;
/*     */ import com.netapp.asup.client.arma.ARMAObjectFactory;
/*     */ import com.netapp.asup.client.arma.ResultIdentifier;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.data.objects.Identifier;
/*     */ import com.netapp.asup.data.store.BaseContainer;
/*     */ import com.netapp.asup.data.store.StoreContainer;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import com.netapp.asup.exception.ARMAIllegalArgumentException;
/*     */ import com.netapp.asupdata.client.ARMA.utils.IdentifierUtils;
/*     */ import org.apache.commons.lang.StringUtils;
/*     */ 
/*     */ 
/*     */ public class ARMAObjectFactoryImpl
/*     */   implements ARMAObjectFactory
/*     */ {
/*  19 */   private static final AsupLogger LOG = AsupLogger.getLogger(ARMAObjectFactoryImpl.class);
/*     */   private static ARMAException armaException;
/*     */   
/*     */   static
/*     */   {
/*     */     try
/*     */     {
/*  26 */       BaseContainer.getInstance().initializeContainer();
/*     */     } catch (Exception e) {
/*  28 */       armaException = new ARMAException(LOG, "-9999", "Continer initialization failed", e);
/*     */     }
/*     */   }
/*     */   
/*     */   public ARMAObjectFactoryImpl()
/*     */     throws ARMAException
/*     */   {
/*  35 */     if (null != armaException) {
/*  36 */       throw armaException;
/*     */     }
/*     */   }
/*     */   
/*     */   public ARMAObject getRoot(String clusterId, String timeStamp)
/*     */     throws ARMAException
/*     */   {
/*  43 */     return getRoot(clusterId, timeStamp, Boolean.FALSE.booleanValue());
/*     */   }
/*     */   
/*     */   public ARMAObject getRoot(String systemId, String sysSerialNo, String timeStamp)
/*     */     throws ARMAException
/*     */   {
/*  49 */     return getRoot(systemId, sysSerialNo, timeStamp, Boolean.FALSE.booleanValue());
/*     */   }
/*     */   
/*     */   public ARMAObject getRoot(String bizKey) throws ARMAException {
/*  53 */     return getRoot(bizKey, Boolean.FALSE.booleanValue());
/*     */   }
/*     */   
/*     */   public ARMAObject getGraphRoot(Identifier id, boolean isClusterAsRoot) throws ARMAException
/*     */   {
/*  58 */     id.setClusterRoot(String.valueOf(isClusterAsRoot));
/*  59 */     ARMAClientSession newSession = new ARMAClientSession(id);
/*  60 */     return newSession.getRootObject();
/*     */   }
/*     */   
/*     */   public ARMAObject getRoot(String clusterId, String timeStamp, boolean isSecureUser)
/*     */     throws ARMAException
/*     */   {
/*  66 */     validateClusterId(clusterId);
/*     */     
/*  68 */     Identifier id = Identifier.initialize(clusterId, timeStamp, isSecureUser);
/*  69 */     return getGraphRoot(id, true);
/*     */   }
/*     */   
/*     */   public ARMAObject getRoot(String systemId, String sysSerialNo, String timeStamp, boolean isSecureUser)
/*     */     throws ARMAException
/*     */   {
/*  75 */     validateSystemId(systemId);
/*  76 */     if (StringUtils.isEmpty(sysSerialNo)) {
/*  77 */       String message = "Invalid System Serial Number:" + systemId;
/*  78 */       throw new ARMAIllegalArgumentException(LOG, message);
/*     */     }
/*     */     
/*  81 */     Identifier id = Identifier.initialize(systemId, sysSerialNo, timeStamp, isSecureUser);
/*  82 */     return getGraphRoot(id, false);
/*     */   }
/*     */   
/*     */   public ARMAObject getRoot(String bizKey, boolean isSecureUser)
/*     */     throws ARMAException
/*     */   {
/*  88 */     if (StringUtils.isEmpty(bizKey)) {
/*  89 */       String message = "Invalid biz key:" + bizKey;
/*  90 */       throw new ARMAIllegalArgumentException(LOG, message);
/*     */     }
/*     */     
/*  93 */     Identifier id = Identifier.initialize(bizKey, isSecureUser);
/*  94 */     return getGraphRoot(id, IdentifierUtils.isClusterRoot(bizKey));
/*     */   }
/*     */   
/*     */   public <T> ARMAObject getRoot(ResultIdentifier<T> resultId, boolean isSecureUser)
/*     */     throws ARMAException
/*     */   {
/* 100 */     StoreContainer storeContainer = BaseContainer.getInstance().getStoreContainer();
/*     */     
/* 102 */     ResultInitializer resultInitializer = storeContainer.getResultInitializer();
/*     */     
/* 104 */     if (null == resultInitializer) {
/* 105 */       throw new UnsupportedOperationException("Result initialization is not supported in this mode." + storeContainer.getMode());
/*     */     }
/*     */     
/*     */ 
/* 109 */     return resultInitializer.initializeRoot(resultId, isSecureUser);
/*     */   }
/*     */   
/*     */ 
/*     */   public ARMAObject getRootview(String clusterId, String sysId, boolean isSecureUser)
/*     */     throws ARMAException
/*     */   {
/* 116 */     validateClusterId(clusterId);
/* 117 */     validateSystemId(sysId);
/* 118 */     Identifier id = Identifier.initialize(clusterId, sysId, null, isSecureUser, Boolean.TRUE.booleanValue());
/* 119 */     return getGraphRoot(id, true);
/*     */   }
/*     */   
/*     */   public ARMAObject getRootview(String clusterId, String sysId, String timeStamp, boolean isSecureUser)
/*     */     throws ARMAException
/*     */   {
/* 125 */     validateClusterId(clusterId);
/* 126 */     validateSystemId(sysId);
/* 127 */     Identifier id = Identifier.initialize(clusterId, sysId, timeStamp, isSecureUser, Boolean.TRUE.booleanValue());
/* 128 */     return getGraphRoot(id, true);
/*     */   }
/*     */   
/*     */   private void validateClusterId(String clusterId) throws ARMAIllegalArgumentException
/*     */   {
/* 133 */     if (StringUtils.isEmpty(clusterId)) {
/* 134 */       String message = "Invalid Cluter id:" + clusterId;
/* 135 */       throw new ARMAIllegalArgumentException(LOG, message);
/*     */     }
/*     */   }
/*     */   
/*     */   private void validateSystemId(String systemId) throws ARMAIllegalArgumentException
/*     */   {
/* 141 */     if (StringUtils.isEmpty(systemId)) {
/* 142 */       String message = "Invalid System id:" + systemId;
/* 143 */       throw new ARMAIllegalArgumentException(LOG, message);
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asupdata\client\ARMA\ARMAObjectFactoryImpl.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */