/*     */ package com.sun.xml.bind.v2.model.impl;
/*     */ 
/*     */ import com.sun.xml.bind.v2.model.annotation.AnnotationReader;
/*     */ import com.sun.xml.bind.v2.model.annotation.Locatable;
/*     */ import com.sun.xml.bind.v2.model.core.ErrorHandler;
/*     */ import com.sun.xml.bind.v2.model.core.NonElement;
/*     */ import com.sun.xml.bind.v2.model.core.PropertyInfo;
/*     */ import com.sun.xml.bind.v2.model.core.PropertyKind;
/*     */ import com.sun.xml.bind.v2.model.core.Ref;
/*     */ import com.sun.xml.bind.v2.model.core.RegistryInfo;
/*     */ import com.sun.xml.bind.v2.model.core.TypeInfo;
/*     */ import com.sun.xml.bind.v2.model.core.TypeInfoSet;
/*     */ import com.sun.xml.bind.v2.model.nav.Navigator;
/*     */ import com.sun.xml.bind.v2.runtime.IllegalAnnotationException;
/*     */ import java.util.Collection;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.Map;
/*     */ import javax.xml.bind.annotation.XmlRegistry;
/*     */ import javax.xml.namespace.QName;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ModelBuilder<T, C, F, M>
/*     */ {
/*     */   final TypeInfoSetImpl<T, C, F, M> typeInfoSet;
/*     */   public final AnnotationReader<T, C, F, M> reader;
/*     */   public final Navigator<T, C, F, M> nav;
/*  51 */   private final Map<QName, TypeInfo> typeNames = new HashMap();
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final String defaultNsUri;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  71 */   final Map<String, RegistryInfoImpl> registries = new HashMap();
/*     */   
/*     */ 
/*     */   private ErrorHandler errorHandler;
/*     */   
/*     */ 
/*     */   private boolean hadError;
/*     */   
/*  79 */   private final ErrorHandler proxyErrorHandler = new ErrorHandler() {
/*     */     public void error(IllegalAnnotationException e) {
/*  81 */       ModelBuilder.this.reportError(e);
/*     */     }
/*     */   };
/*     */   
/*     */ 
/*     */   private boolean linked;
/*     */   
/*     */ 
/*     */   public ModelBuilder(AnnotationReader<T, C, F, M> reader, Navigator<T, C, F, M> navigator, String defaultNamespaceRemap)
/*     */   {
/*  91 */     this.reader = reader;
/*  92 */     this.nav = navigator;
/*  93 */     if (defaultNamespaceRemap == null)
/*  94 */       defaultNamespaceRemap = "";
/*  95 */     this.defaultNsUri = defaultNamespaceRemap;
/*  96 */     reader.setErrorHandler(this.proxyErrorHandler);
/*  97 */     this.typeInfoSet = createTypeInfoSet();
/*     */   }
/*     */   
/*     */   protected TypeInfoSetImpl<T, C, F, M> createTypeInfoSet() {
/* 101 */     return new TypeInfoSetImpl(this.nav, this.reader, BuiltinLeafInfoImpl.createLeaves(this.nav));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public NonElement<T, C> getClassInfo(C clazz, Locatable upstream)
/*     */   {
/* 113 */     assert (clazz != null);
/* 114 */     NonElement<T, C> r = this.typeInfoSet.getClassInfo(clazz);
/* 115 */     if (r != null) {
/* 116 */       return r;
/*     */     }
/* 118 */     if (this.nav.isEnum(clazz)) {
/* 119 */       EnumLeafInfoImpl<T, C, F, M> li = createEnumLeafInfo(clazz, upstream);
/* 120 */       this.typeInfoSet.add(li);
/* 121 */       r = li;
/*     */     } else {
/* 123 */       ClassInfoImpl<T, C, F, M> ci = createClassInfo(clazz, upstream);
/* 124 */       this.typeInfoSet.add(ci);
/*     */       
/*     */ 
/* 127 */       for (PropertyInfo<T, C> p : ci.getProperties()) {
/* 128 */         if (p.kind() == PropertyKind.REFERENCE)
/*     */         {
/* 130 */           String pkg = this.nav.getPackageName(ci.getClazz());
/* 131 */           if (!this.registries.containsKey(pkg))
/*     */           {
/* 133 */             C c = this.nav.findClass(pkg + ".ObjectFactory", ci.getClazz());
/* 134 */             if (c != null) {
/* 135 */               addRegistry(c, (Locatable)p);
/*     */             }
/*     */           }
/*     */         }
/* 139 */         for (Iterator i$ = p.ref().iterator(); i$.hasNext(); t = (TypeInfo)i$.next()) {}
/*     */       }
/*     */       TypeInfo<T, C> t;
/* 142 */       ci.getBaseClass();
/*     */       
/* 144 */       r = ci;
/*     */     }
/*     */     
/* 147 */     addTypeName(r);
/*     */     
/* 149 */     return r;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   private void addTypeName(NonElement<T, C> r)
/*     */   {
/* 156 */     QName t = r.getTypeName();
/* 157 */     if (t == null) { return;
/*     */     }
/* 159 */     TypeInfo old = (TypeInfo)this.typeNames.put(t, r);
/* 160 */     if (old != null)
/*     */     {
/* 162 */       reportError(new IllegalAnnotationException(Messages.CONFLICTING_XML_TYPE_MAPPING.format(new Object[] { r.getTypeName() }), old, r));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public NonElement<T, C> getTypeInfo(T t, Locatable upstream)
/*     */   {
/* 176 */     NonElement<T, C> r = this.typeInfoSet.getTypeInfo(t);
/* 177 */     if (r != null) { return r;
/*     */     }
/* 179 */     if (this.nav.isArray(t)) {
/* 180 */       ArrayInfoImpl<T, C, F, M> ai = createArrayInfo(upstream, t);
/*     */       
/* 182 */       addTypeName(ai);
/* 183 */       this.typeInfoSet.add(ai);
/* 184 */       return ai;
/*     */     }
/*     */     
/* 187 */     C c = this.nav.asDecl(t);
/* 188 */     assert (c != null) : (t.toString() + " must be a leaf, but we failed to recognize it.");
/* 189 */     return getClassInfo(c, upstream);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public NonElement<T, C> getTypeInfo(Ref<T, C> ref)
/*     */   {
/* 197 */     assert (!ref.valueList);
/* 198 */     C c = this.nav.asDecl(ref.type);
/* 199 */     if ((c != null) && (this.reader.getClassAnnotation(XmlRegistry.class, c, null) != null)) {
/* 200 */       if (!this.registries.containsKey(this.nav.getPackageName(c)))
/* 201 */         addRegistry(c, null);
/* 202 */       return null;
/*     */     }
/* 204 */     return getTypeInfo(ref.type, null);
/*     */   }
/*     */   
/*     */   protected EnumLeafInfoImpl<T, C, F, M> createEnumLeafInfo(C clazz, Locatable upstream)
/*     */   {
/* 209 */     return new EnumLeafInfoImpl(this, upstream, clazz, this.nav.use(clazz));
/*     */   }
/*     */   
/*     */   protected ClassInfoImpl<T, C, F, M> createClassInfo(C clazz, Locatable upstream)
/*     */   {
/* 214 */     return new ClassInfoImpl(this, upstream, clazz);
/*     */   }
/*     */   
/*     */   protected ElementInfoImpl<T, C, F, M> createElementInfo(RegistryInfoImpl<T, C, F, M> registryInfo, M m) throws IllegalAnnotationException
/*     */   {
/* 219 */     return new ElementInfoImpl(this, registryInfo, m);
/*     */   }
/*     */   
/*     */   protected ArrayInfoImpl<T, C, F, M> createArrayInfo(Locatable upstream, T arrayType) {
/* 223 */     return new ArrayInfoImpl(this, upstream, arrayType);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public RegistryInfo<T, C> addRegistry(C registryClass, Locatable upstream)
/*     */   {
/* 232 */     RegistryInfoImpl<T, C, F, M> r = new RegistryInfoImpl(this, upstream, registryClass);
/* 233 */     return r;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public RegistryInfo<T, C> getRegistry(String packageName)
/*     */   {
/* 245 */     return (RegistryInfo)this.registries.get(packageName);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public TypeInfoSet<T, C, F, M> link()
/*     */   {
/* 263 */     assert (!this.linked);
/* 264 */     this.linked = true;
/*     */     
/* 266 */     for (ElementInfoImpl ei : this.typeInfoSet.getAllElements()) {
/* 267 */       ei.link();
/*     */     }
/* 269 */     for (ClassInfoImpl ci : this.typeInfoSet.beans().values()) {
/* 270 */       ci.link();
/*     */     }
/* 272 */     for (EnumLeafInfoImpl li : this.typeInfoSet.enums().values()) {
/* 273 */       li.link();
/*     */     }
/* 275 */     if (this.hadError) {
/* 276 */       return null;
/*     */     }
/* 278 */     return this.typeInfoSet;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setErrorHandler(ErrorHandler errorHandler)
/*     */   {
/* 294 */     this.errorHandler = errorHandler;
/*     */   }
/*     */   
/*     */   public final void reportError(IllegalAnnotationException e) {
/* 298 */     this.hadError = true;
/* 299 */     if (this.errorHandler != null) {
/* 300 */       this.errorHandler.error(e);
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\target\myautosupport\WEB-INF\lib\jaxb-impl-2.0.3.jar!\com\sun\xml\bind\v2\model\impl\ModelBuilder.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */