/*     */ package com.sun.xml.txw2;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ class StartTag
/*     */   extends Content
/*     */   implements NamespaceResolver
/*     */ {
/*     */   private String uri;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   private final String localName;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   private Attribute firstAtt;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   private Attribute lastAtt;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   private ContainerElement owner;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   private NamespaceDecl firstNs;
/*     */   
/*     */ 
/*     */ 
/*     */   private NamespaceDecl lastNs;
/*     */   
/*     */ 
/*     */ 
/*     */   final Document document;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public StartTag(ContainerElement owner, String uri, String localName)
/*     */   {
/*  51 */     this(owner.document, uri, localName);
/*  52 */     this.owner = owner;
/*     */   }
/*     */   
/*     */   public StartTag(Document document, String uri, String localName) {
/*  56 */     assert (uri != null);
/*  57 */     assert (localName != null);
/*     */     
/*  59 */     this.uri = uri;
/*  60 */     this.localName = localName;
/*  61 */     this.document = document;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*  66 */     addNamespaceDecl(uri, null, false);
/*     */   }
/*     */   
/*     */   public void addAttribute(String nsUri, String localName, Object arg) {
/*  70 */     checkWritable();
/*     */     
/*     */ 
/*     */ 
/*  74 */     for (Attribute a = this.firstAtt; (a != null) && 
/*  75 */           (!a.hasName(nsUri, localName)); a = a.next) {}
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  81 */     if (a == null) {
/*  82 */       a = new Attribute(nsUri, localName);
/*  83 */       if (this.lastAtt == null) {
/*  84 */         assert (this.firstAtt == null);
/*  85 */         this.firstAtt = (this.lastAtt = a);
/*     */       } else {
/*  87 */         assert (this.firstAtt != null);
/*  88 */         this.lastAtt.next = a;
/*  89 */         this.lastAtt = a;
/*     */       }
/*  91 */       if (nsUri.length() > 0) {
/*  92 */         addNamespaceDecl(nsUri, null, true);
/*     */       }
/*     */     }
/*  95 */     this.document.writeValue(arg, this, a.value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public NamespaceDecl addNamespaceDecl(String uri, String prefix, boolean requirePrefix)
/*     */   {
/* 118 */     checkWritable();
/*     */     
/* 120 */     if (uri == null)
/* 121 */       throw new IllegalArgumentException();
/* 122 */     if (uri.length() == 0) {
/* 123 */       if (requirePrefix)
/* 124 */         throw new IllegalArgumentException("The empty namespace cannot have a non-empty prefix");
/* 125 */       if ((prefix != null) && (prefix.length() > 0))
/* 126 */         throw new IllegalArgumentException("The empty namespace can be only bound to the empty prefix");
/* 127 */       prefix = "";
/*     */     }
/*     */     
/*     */ 
/* 131 */     for (NamespaceDecl n = this.firstNs; n != null; n = n.next) {
/* 132 */       if (uri.equals(n.uri)) {
/* 133 */         if (prefix == null)
/*     */         {
/* 135 */           n.requirePrefix |= requirePrefix;
/* 136 */           return n;
/*     */         }
/* 138 */         if (n.prefix == null)
/*     */         {
/* 140 */           n.prefix = prefix;
/* 141 */           n.requirePrefix |= requirePrefix;
/* 142 */           return n;
/*     */         }
/* 144 */         if (prefix.equals(n.prefix))
/*     */         {
/* 146 */           n.requirePrefix |= requirePrefix;
/* 147 */           return n;
/*     */         }
/*     */       }
/* 150 */       if ((prefix != null) && (n.prefix != null) && (n.prefix.equals(prefix))) {
/* 151 */         throw new IllegalArgumentException("Prefix '" + prefix + "' is already bound to '" + n.uri + '\'');
/*     */       }
/*     */     }
/*     */     
/* 155 */     NamespaceDecl ns = new NamespaceDecl(this.document.assignNewId(), uri, prefix, requirePrefix);
/* 156 */     if (this.lastNs == null) {
/* 157 */       assert (this.firstNs == null);
/* 158 */       this.firstNs = (this.lastNs = ns);
/*     */     } else {
/* 160 */       assert (this.firstNs != null);
/* 161 */       this.lastNs.next = ns;
/* 162 */       this.lastNs = ns;
/*     */     }
/* 164 */     return ns;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   private void checkWritable()
/*     */   {
/* 171 */     if (isWritten()) {
/* 172 */       throw new IllegalStateException("The start tag of " + this.localName + " has already been written. " + "If you need out of order writing, see the TypedXmlWriter.block method");
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   boolean isWritten()
/*     */   {
/* 181 */     return this.uri == null;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   boolean isReadyToCommit()
/*     */   {
/* 189 */     if ((this.owner != null) && (this.owner.isBlocked())) {
/* 190 */       return false;
/*     */     }
/* 192 */     for (Content c = getNext(); c != null; c = c.getNext()) {
/* 193 */       if (c.concludesPendingStartTag())
/* 194 */         return true;
/*     */     }
/* 196 */     return false;
/*     */   }
/*     */   
/*     */   public void written() {
/* 200 */     this.firstAtt = (this.lastAtt = null);
/* 201 */     this.uri = null;
/* 202 */     if (this.owner != null) {
/* 203 */       assert (this.owner.startTag == this);
/* 204 */       this.owner.startTag = null;
/*     */     }
/*     */   }
/*     */   
/*     */   boolean concludesPendingStartTag() {
/* 209 */     return true;
/*     */   }
/*     */   
/*     */   void accept(ContentVisitor visitor) {
/* 213 */     visitor.onStartTag(this.uri, this.localName, this.firstAtt, this.firstNs);
/*     */   }
/*     */   
/*     */   public String getPrefix(String nsUri) {
/* 217 */     NamespaceDecl ns = addNamespaceDecl(nsUri, null, false);
/* 218 */     if (ns.prefix != null)
/*     */     {
/* 220 */       return ns.prefix; }
/* 221 */     return ns.dummyPrefix;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\target\myautosupport\WEB-INF\lib\jaxb-impl-2.0.3.jar!\com\sun\xml\txw2\StartTag.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */