/*     */ package com.sun.xml.txw2.output;
/*     */ 
/*     */ import com.sun.xml.txw2.TxwException;
/*     */ import java.util.Stack;
/*     */ import javax.xml.transform.sax.SAXResult;
/*     */ import org.xml.sax.ContentHandler;
/*     */ import org.xml.sax.SAXException;
/*     */ import org.xml.sax.ext.LexicalHandler;
/*     */ import org.xml.sax.helpers.AttributesImpl;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SaxSerializer
/*     */   implements XmlSerializer
/*     */ {
/*     */   private final ContentHandler writer;
/*     */   private final LexicalHandler lexical;
/*     */   
/*     */   public SaxSerializer(ContentHandler handler)
/*     */   {
/*  23 */     this(handler, null);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public SaxSerializer(ContentHandler handler, LexicalHandler lex)
/*     */   {
/*  34 */     this.writer = handler;
/*  35 */     this.lexical = lex;
/*     */   }
/*     */   
/*     */   public SaxSerializer(SAXResult result) {
/*  39 */     this(result.getHandler(), result.getLexicalHandler());
/*     */   }
/*     */   
/*     */ 
/*     */   public void startDocument()
/*     */   {
/*     */     try
/*     */     {
/*  47 */       this.writer.startDocument();
/*     */     } catch (SAXException e) {
/*  49 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*  55 */   private final Stack<String> prefixBindings = new Stack();
/*     */   
/*     */   public void writeXmlns(String prefix, String uri)
/*     */   {
/*  59 */     if (prefix == null) {
/*  60 */       prefix = "";
/*     */     }
/*     */     
/*  63 */     if (prefix.equals("xml")) {
/*  64 */       return;
/*     */     }
/*     */     
/*  67 */     this.prefixBindings.add(uri);
/*  68 */     this.prefixBindings.add(prefix);
/*     */   }
/*     */   
/*     */ 
/*  72 */   private final Stack<String> elementBindings = new Stack();
/*     */   
/*     */   public void beginStartTag(String uri, String localName, String prefix)
/*     */   {
/*  76 */     this.elementBindings.add(getQName(prefix, localName));
/*  77 */     this.elementBindings.add(localName);
/*  78 */     this.elementBindings.add(uri);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*  84 */   private final AttributesImpl attrs = new AttributesImpl();
/*     */   
/*     */   public void writeAttribute(String uri, String localName, String prefix, StringBuilder value) {
/*  87 */     this.attrs.addAttribute(uri, localName, getQName(prefix, localName), "CDATA", value.toString());
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void endStartTag(String uri, String localName, String prefix)
/*     */   {
/*     */     try
/*     */     {
/*  96 */       while (this.prefixBindings.size() != 0) {
/*  97 */         this.writer.startPrefixMapping((String)this.prefixBindings.pop(), (String)this.prefixBindings.pop());
/*     */       }
/*     */       
/*     */ 
/*     */ 
/* 102 */       this.writer.startElement(uri, localName, getQName(prefix, localName), this.attrs);
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 107 */       this.attrs.clear();
/*     */     } catch (SAXException e) {
/* 109 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void endTag() {
/*     */     try {
/* 115 */       this.writer.endElement((String)this.elementBindings.pop(), (String)this.elementBindings.pop(), (String)this.elementBindings.pop());
/*     */ 
/*     */     }
/*     */     catch (SAXException e)
/*     */     {
/* 120 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void text(StringBuilder text) {
/*     */     try {
/* 126 */       this.writer.characters(text.toString().toCharArray(), 0, text.length());
/*     */     } catch (SAXException e) {
/* 128 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void cdata(StringBuilder text) {
/* 133 */     if (this.lexical == null) {
/* 134 */       throw new UnsupportedOperationException("LexicalHandler is needed to write PCDATA");
/*     */     }
/*     */     try {
/* 137 */       this.lexical.startCDATA();
/* 138 */       text(text);
/* 139 */       this.lexical.endCDATA();
/*     */     } catch (SAXException e) {
/* 141 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void comment(StringBuilder comment) {
/*     */     try {
/* 147 */       if (this.lexical == null) {
/* 148 */         throw new UnsupportedOperationException("LexicalHandler is needed to write comments");
/*     */       }
/* 150 */       this.lexical.comment(comment.toString().toCharArray(), 0, comment.length());
/*     */     } catch (SAXException e) {
/* 152 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */   public void endDocument() {
/*     */     try {
/* 158 */       this.writer.endDocument();
/*     */     } catch (SAXException e) {
/* 160 */       throw new TxwException(e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public void flush() {}
/*     */   
/*     */   private static String getQName(String prefix, String localName)
/*     */   {
/*     */     String qName;
/*     */     String qName;
/* 171 */     if ((prefix == null) || (prefix.length() == 0)) {
/* 172 */       qName = localName;
/*     */     } else {
/* 174 */       qName = prefix + ':' + localName;
/*     */     }
/* 176 */     return qName;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\target\myautosupport\WEB-INF\lib\jaxb-impl-2.0.3.jar!\com\sun\xml\txw2\output\SaxSerializer.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */