/*     */ package com.thoughtworks.paranamer;
/*     */ 
/*     */ import java.lang.reflect.AccessibleObject;
/*     */ import java.lang.reflect.Constructor;
/*     */ import java.lang.reflect.Field;
/*     */ import java.lang.reflect.Method;
/*     */ import java.lang.reflect.Modifier;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class DefaultParanamer
/*     */   implements Paranamer
/*     */ {
/*     */   private static final String COMMA = ",";
/*     */   private static final String SPACE = " ";
/*     */   public static final String __PARANAMER_DATA = "v1.0 \nlookupParameterNames java.lang.AccessibleObject methodOrConstructor \nlookupParameterNames java.lang.AccessibleObject,boolean methodOrCtor,throwExceptionIfMissing \ngetParameterTypeName java.lang.Class cls\n";
/*     */   
/*     */   public String[] lookupParameterNames(AccessibleObject methodOrConstructor)
/*     */   {
/*  60 */     return lookupParameterNames(methodOrConstructor, true);
/*     */   }
/*     */   
/*     */   public String[] lookupParameterNames(AccessibleObject methodOrCtor, boolean throwExceptionIfMissing)
/*     */   {
/*  65 */     Class<?>[] types = null;
/*  66 */     Class<?> declaringClass = null;
/*  67 */     String name = null;
/*  68 */     if ((methodOrCtor instanceof Method)) {
/*  69 */       Method method = (Method)methodOrCtor;
/*  70 */       types = method.getParameterTypes();
/*  71 */       name = method.getName();
/*  72 */       declaringClass = method.getDeclaringClass();
/*     */     } else {
/*  74 */       Constructor<?> constructor = (Constructor)methodOrCtor;
/*  75 */       types = constructor.getParameterTypes();
/*  76 */       declaringClass = constructor.getDeclaringClass();
/*  77 */       name = "<init>";
/*     */     }
/*     */     
/*  80 */     if (types.length == 0) {
/*  81 */       return EMPTY_NAMES;
/*     */     }
/*  83 */     String parameterTypeNames = getParameterTypeNamesCSV(types);
/*  84 */     String[] names = getParameterNames(declaringClass, parameterTypeNames, name + " ");
/*  85 */     if (names == null) {
/*  86 */       if (throwExceptionIfMissing) {
/*  87 */         throw new ParameterNamesNotFoundException("No parameter names found for class '" + declaringClass + "', methodOrCtor " + name + " and parameter types " + parameterTypeNames);
/*     */       }
/*     */       
/*  90 */       return Paranamer.EMPTY_NAMES;
/*     */     }
/*     */     
/*  93 */     return names;
/*     */   }
/*     */   
/*     */   private static String[] getParameterNames(Class<?> declaringClass, String parameterTypes, String prefix) {
/*  97 */     String data = getParameterListResource(declaringClass);
/*  98 */     String line = findFirstMatchingLine(data, prefix + parameterTypes + " ");
/*  99 */     String[] parts = line.split(" ");
/*     */     
/* 101 */     if ((parts.length == 3) && (parts[1].equals(parameterTypes))) {
/* 102 */       String parameterNames = parts[2];
/* 103 */       return parameterNames.split(",");
/*     */     }
/* 105 */     return Paranamer.EMPTY_NAMES;
/*     */   }
/*     */   
/*     */   static String getParameterTypeNamesCSV(Class<?>[] parameterTypes) {
/* 109 */     StringBuffer sb = new StringBuffer();
/* 110 */     for (int i = 0; i < parameterTypes.length; i++) {
/* 111 */       sb.append(getParameterTypeName(parameterTypes[i]));
/* 112 */       if (i < parameterTypes.length - 1) {
/* 113 */         sb.append(",");
/*     */       }
/*     */     }
/* 116 */     return sb.toString();
/*     */   }
/*     */   
/*     */   private static String getParameterListResource(Class<?> declaringClass) {
/*     */     try {
/* 121 */       Field field = declaringClass.getDeclaredField("__PARANAMER_DATA");
/*     */       
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 127 */       if ((!Modifier.isStatic(field.getModifiers())) || (!field.getType().equals(String.class))) {
/* 128 */         return null;
/*     */       }
/* 130 */       return (String)field.get(null);
/*     */     } catch (NoSuchFieldException e) {
/* 132 */       return null;
/*     */     } catch (IllegalAccessException e) {}
/* 134 */     return null;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private static String findFirstMatchingLine(String data, String prefix)
/*     */   {
/* 145 */     if (data == null) {
/* 146 */       return "";
/*     */     }
/* 148 */     int ix = data.indexOf(prefix);
/* 149 */     if (ix >= 0) {
/* 150 */       int iy = data.indexOf("\n", ix);
/* 151 */       if (iy > 0) {
/* 152 */         return data.substring(ix, iy);
/*     */       }
/*     */     }
/* 155 */     return "";
/*     */   }
/*     */   
/*     */   private static String getParameterTypeName(Class<?> cls)
/*     */   {
/* 160 */     String parameterTypeNameName = cls.getName();
/* 161 */     int arrayNestingDepth = 0;
/* 162 */     int ix = parameterTypeNameName.indexOf("[");
/* 163 */     while (ix > -1) {
/* 164 */       arrayNestingDepth++;
/* 165 */       parameterTypeNameName = parameterTypeNameName.replaceFirst("(\\[\\w)|(\\[)", "");
/* 166 */       ix = parameterTypeNameName.indexOf("[");
/*     */     }
/* 168 */     parameterTypeNameName = parameterTypeNameName.replaceFirst(";", "");
/* 169 */     for (int k = 0; k < arrayNestingDepth; k++) {
/* 170 */       parameterTypeNameName = parameterTypeNameName + "[]";
/*     */     }
/* 172 */     return parameterTypeNameName;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\thoughtworks\paranamer\DefaultParanamer.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */