/*     */ package org.apache.avro.generic;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.nio.ByteBuffer;
/*     */ import java.util.Collection;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Map.Entry;
/*     */ import org.apache.avro.AvroTypeException;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.Schema.Field;
/*     */ import org.apache.avro.io.DatumWriter;
/*     */ import org.apache.avro.io.Encoder;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class GenericDatumWriter<D>
/*     */   implements DatumWriter<D>
/*     */ {
/*     */   private final GenericData data;
/*     */   private Schema root;
/*     */   
/*  37 */   public GenericDatumWriter() { this(GenericData.get()); }
/*     */   
/*  39 */   protected GenericDatumWriter(GenericData data) { this.data = data; }
/*     */   
/*     */   public GenericDatumWriter(Schema root) {
/*  42 */     this();
/*  43 */     setSchema(root);
/*     */   }
/*     */   
/*     */   protected GenericDatumWriter(Schema root, GenericData data) {
/*  47 */     this(data);
/*  48 */     setSchema(root);
/*     */   }
/*     */   
/*     */ 
/*  52 */   public GenericData getData() { return this.data; }
/*     */   
/*  54 */   public void setSchema(Schema root) { this.root = root; }
/*     */   
/*     */   public void write(D datum, Encoder out) throws IOException {
/*  57 */     write(this.root, datum, out);
/*     */   }
/*     */   
/*     */   protected void write(Schema schema, Object datum, Encoder out) throws IOException
/*     */   {
/*     */     try
/*     */     {
/*  64 */       switch (schema.getType()) {
/*  65 */       case RECORD:  writeRecord(schema, datum, out); break;
/*  66 */       case ENUM:  writeEnum(schema, datum, out); break;
/*  67 */       case ARRAY:  writeArray(schema, datum, out); break;
/*  68 */       case MAP:  writeMap(schema, datum, out); break;
/*     */       case UNION: 
/*  70 */         int index = resolveUnion(schema, datum);
/*  71 */         out.writeIndex(index);
/*  72 */         write((Schema)schema.getTypes().get(index), datum, out);
/*  73 */         break;
/*  74 */       case FIXED:  writeFixed(schema, datum, out); break;
/*  75 */       case STRING:  writeString(schema, datum, out); break;
/*  76 */       case BYTES:  writeBytes(datum, out); break;
/*  77 */       case INT:  out.writeInt(((Number)datum).intValue()); break;
/*  78 */       case LONG:  out.writeLong(((Long)datum).longValue()); break;
/*  79 */       case FLOAT:  out.writeFloat(((Float)datum).floatValue()); break;
/*  80 */       case DOUBLE:  out.writeDouble(((Double)datum).doubleValue()); break;
/*  81 */       case BOOLEAN:  out.writeBoolean(((Boolean)datum).booleanValue()); break;
/*  82 */       case NULL:  out.writeNull(); break;
/*  83 */       default:  error(schema, datum);
/*     */       }
/*     */     } catch (NullPointerException e) {
/*  86 */       throw npe(e, " of " + schema.getFullName());
/*     */     }
/*     */   }
/*     */   
/*     */   protected NullPointerException npe(NullPointerException e, String s)
/*     */   {
/*  92 */     NullPointerException result = new NullPointerException(e.getMessage() + s);
/*  93 */     result.initCause(e.getCause() == null ? e : e.getCause());
/*  94 */     return result;
/*     */   }
/*     */   
/*     */ 
/*     */   protected void writeRecord(Schema schema, Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 101 */     Object state = this.data.getRecordState(datum, schema);
/* 102 */     for (Schema.Field f : schema.getFields()) {
/* 103 */       Object value = this.data.getField(datum, f.name(), f.pos(), state);
/*     */       try {
/* 105 */         write(f.schema(), value, out);
/*     */       } catch (NullPointerException e) {
/* 107 */         throw npe(e, " in field " + f.name());
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   protected void writeEnum(Schema schema, Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 116 */     out.writeEnum(schema.getEnumOrdinal(datum.toString()));
/*     */   }
/*     */   
/*     */ 
/*     */   protected void writeArray(Schema schema, Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 123 */     Schema element = schema.getElementType();
/* 124 */     long size = getArraySize(datum);
/* 125 */     out.writeArrayStart();
/* 126 */     out.setItemCount(size);
/* 127 */     for (Iterator<? extends Object> it = getArrayElements(datum); it.hasNext();) {
/* 128 */       out.startItem();
/* 129 */       write(element, it.next(), out);
/*     */     }
/* 131 */     out.writeArrayEnd();
/*     */   }
/*     */   
/*     */ 
/*     */   protected int resolveUnion(Schema union, Object datum)
/*     */   {
/* 137 */     return this.data.resolveUnion(union, datum);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected long getArraySize(Object array)
/*     */   {
/* 144 */     return ((Collection)array).size();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected Iterator<? extends Object> getArrayElements(Object array)
/*     */   {
/* 151 */     return ((Collection)array).iterator();
/*     */   }
/*     */   
/*     */ 
/*     */   protected void writeMap(Schema schema, Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 158 */     Schema value = schema.getValueType();
/* 159 */     int size = getMapSize(datum);
/* 160 */     out.writeMapStart();
/* 161 */     out.setItemCount(size);
/* 162 */     for (Map.Entry<Object, Object> entry : getMapEntries(datum)) {
/* 163 */       out.startItem();
/* 164 */       writeString(entry.getKey(), out);
/* 165 */       write(value, entry.getValue(), out);
/*     */     }
/* 167 */     out.writeMapEnd();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected int getMapSize(Object map)
/*     */   {
/* 174 */     return ((Map)map).size();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected Iterable<Map.Entry<Object, Object>> getMapEntries(Object map)
/*     */   {
/* 181 */     return ((Map)map).entrySet();
/*     */   }
/*     */   
/*     */ 
/*     */   protected void writeString(Schema schema, Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 188 */     writeString(datum, out);
/*     */   }
/*     */   
/*     */   protected void writeString(Object datum, Encoder out) throws IOException
/*     */   {
/* 193 */     out.writeString((CharSequence)datum);
/*     */   }
/*     */   
/*     */   protected void writeBytes(Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 199 */     out.writeBytes((ByteBuffer)datum);
/*     */   }
/*     */   
/*     */ 
/*     */   protected void writeFixed(Schema schema, Object datum, Encoder out)
/*     */     throws IOException
/*     */   {
/* 206 */     out.writeFixed(((GenericFixed)datum).bytes(), 0, schema.getFixedSize());
/*     */   }
/*     */   
/*     */   private void error(Schema schema, Object datum) {
/* 210 */     throw new AvroTypeException("Not a " + schema + ": " + datum);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\apache\avro\generic\GenericDatumWriter.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */