/*     */ package org.codehaus.jackson.map.deser.impl;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.lang.reflect.Constructor;
/*     */ import java.util.Collection;
/*     */ import org.codehaus.jackson.JsonParser;
/*     */ import org.codehaus.jackson.JsonProcessingException;
/*     */ import org.codehaus.jackson.JsonToken;
/*     */ import org.codehaus.jackson.map.DeserializationConfig.Feature;
/*     */ import org.codehaus.jackson.map.DeserializationContext;
/*     */ import org.codehaus.jackson.map.JsonDeserializer;
/*     */ import org.codehaus.jackson.map.TypeDeserializer;
/*     */ import org.codehaus.jackson.map.annotate.JacksonStdImpl;
/*     */ import org.codehaus.jackson.map.deser.ContainerDeserializer;
/*     */ import org.codehaus.jackson.type.JavaType;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ @JacksonStdImpl
/*     */ public final class StringCollectionDeserializer
/*     */   extends ContainerDeserializer<Collection<String>>
/*     */ {
/*     */   protected final JavaType _collectionType;
/*     */   protected final JsonDeserializer<String> _valueDeserializer;
/*     */   protected final boolean _isDefaultDeserializer;
/*     */   final Constructor<Collection<String>> _defaultCtor;
/*     */   
/*     */   public StringCollectionDeserializer(JavaType collectionType, JsonDeserializer<?> valueDeser, Constructor<?> ctor)
/*     */   {
/*  49 */     super(collectionType.getRawClass());
/*  50 */     this._collectionType = collectionType;
/*  51 */     this._valueDeserializer = valueDeser;
/*  52 */     this._defaultCtor = ctor;
/*  53 */     this._isDefaultDeserializer = isDefaultSerializer(valueDeser);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JavaType getContentType()
/*     */   {
/*  64 */     return this._collectionType.getContentType();
/*     */   }
/*     */   
/*     */ 
/*     */   public JsonDeserializer<Object> getContentDeserializer()
/*     */   {
/*  70 */     JsonDeserializer<?> deser = this._valueDeserializer;
/*  71 */     return deser;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public Collection<String> deserialize(JsonParser jp, DeserializationContext ctxt)
/*     */     throws IOException, JsonProcessingException
/*     */   {
/*     */     Collection<String> result;
/*     */     
/*     */ 
/*     */ 
/*     */     try
/*     */     {
/*  86 */       result = (Collection)this._defaultCtor.newInstance(new Object[0]);
/*     */     } catch (Exception e) {
/*  88 */       throw ctxt.instantiationException(this._collectionType.getRawClass(), e);
/*     */     }
/*  90 */     return deserialize(jp, ctxt, result);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public Collection<String> deserialize(JsonParser jp, DeserializationContext ctxt, Collection<String> result)
/*     */     throws IOException, JsonProcessingException
/*     */   {
/*  99 */     if (!jp.isExpectedStartArrayToken()) {
/* 100 */       return handleNonArray(jp, ctxt, result);
/*     */     }
/*     */     
/* 103 */     if (!this._isDefaultDeserializer) {
/* 104 */       return deserializeUsingCustom(jp, ctxt, result);
/*     */     }
/*     */     
/*     */     JsonToken t;
/* 108 */     while ((t = jp.nextToken()) != JsonToken.END_ARRAY) {
/* 109 */       result.add(t == JsonToken.VALUE_NULL ? null : jp.getText());
/*     */     }
/* 111 */     return result;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   private Collection<String> deserializeUsingCustom(JsonParser jp, DeserializationContext ctxt, Collection<String> result)
/*     */     throws IOException, JsonProcessingException
/*     */   {
/* 119 */     JsonDeserializer<String> deser = this._valueDeserializer;
/*     */     JsonToken t;
/* 121 */     while ((t = jp.nextToken()) != JsonToken.END_ARRAY) {
/*     */       String value;
/*     */       String value;
/* 124 */       if (t == JsonToken.VALUE_NULL) {
/* 125 */         value = null;
/*     */       } else {
/* 127 */         value = (String)deser.deserialize(jp, ctxt);
/*     */       }
/* 129 */       result.add(value);
/*     */     }
/* 131 */     return result;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public Object deserializeWithType(JsonParser jp, DeserializationContext ctxt, TypeDeserializer typeDeserializer)
/*     */     throws IOException, JsonProcessingException
/*     */   {
/* 140 */     return typeDeserializer.deserializeTypedFromArray(jp, ctxt);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private final Collection<String> handleNonArray(JsonParser jp, DeserializationContext ctxt, Collection<String> result)
/*     */     throws IOException, JsonProcessingException
/*     */   {
/* 153 */     if (!ctxt.isEnabled(DeserializationConfig.Feature.ACCEPT_SINGLE_VALUE_AS_ARRAY)) {
/* 154 */       throw ctxt.mappingException(this._collectionType.getRawClass());
/*     */     }
/*     */     
/* 157 */     JsonDeserializer<String> valueDes = this._valueDeserializer;
/* 158 */     JsonToken t = jp.getCurrentToken();
/*     */     
/*     */     String value;
/*     */     String value;
/* 162 */     if (t == JsonToken.VALUE_NULL) {
/* 163 */       value = null;
/*     */     } else {
/* 165 */       value = valueDes == null ? jp.getText() : (String)valueDes.deserialize(jp, ctxt);
/*     */     }
/* 167 */     result.add(value);
/* 168 */     return result;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\jackson\map\deser\impl\StringCollectionDeserializer.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */