/*     */ package org.codehaus.janino;
/*     */ 
/*     */ import java.io.File;
/*     */ import java.util.HashMap;
/*     */ import java.util.HashSet;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import org.codehaus.janino.util.resource.JarDirectoriesResourceFinder;
/*     */ import org.codehaus.janino.util.resource.PathResourceFinder;
/*     */ import org.codehaus.janino.util.resource.ResourceFinder;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class IClassLoader
/*     */ {
/*     */   private static final boolean DEBUG = false;
/*     */   public IClass OBJECT;
/*     */   public IClass STRING;
/*     */   public IClass CLASS;
/*     */   public IClass THROWABLE;
/*     */   public IClass RUNTIME_EXCEPTION;
/*     */   public IClass ERROR;
/*     */   public IClass CLONEABLE;
/*     */   public IClass SERIALIZABLE;
/*     */   public IClass BOOLEAN;
/*     */   public IClass BYTE;
/*     */   public IClass CHARACTER;
/*     */   public IClass SHORT;
/*     */   public IClass INTEGER;
/*     */   public IClass LONG;
/*     */   public IClass FLOAT;
/*     */   public IClass DOUBLE;
/*     */   private final IClassLoader optionalParentIClassLoader;
/*     */   
/*     */   public IClassLoader(IClassLoader optionalParentIClassLoader)
/*     */   {
/*  66 */     this.optionalParentIClassLoader = optionalParentIClassLoader;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected final void postConstruct()
/*     */   {
/*     */     try
/*     */     {
/*  77 */       this.OBJECT = loadIClass("Ljava/lang/Object;");
/*  78 */       this.STRING = loadIClass("Ljava/lang/String;");
/*  79 */       this.CLASS = loadIClass("Ljava/lang/Class;");
/*  80 */       this.THROWABLE = loadIClass("Ljava/lang/Throwable;");
/*  81 */       this.RUNTIME_EXCEPTION = loadIClass("Ljava/lang/RuntimeException;");
/*  82 */       this.ERROR = loadIClass("Ljava/lang/Error;");
/*  83 */       this.CLONEABLE = loadIClass("Ljava/lang/Cloneable;");
/*  84 */       this.SERIALIZABLE = loadIClass("Ljava/io/Serializable;");
/*  85 */       this.BOOLEAN = loadIClass("Ljava/lang/Boolean;");
/*  86 */       this.BYTE = loadIClass("Ljava/lang/Byte;");
/*  87 */       this.CHARACTER = loadIClass("Ljava/lang/Character;");
/*  88 */       this.SHORT = loadIClass("Ljava/lang/Short;");
/*  89 */       this.INTEGER = loadIClass("Ljava/lang/Integer;");
/*  90 */       this.LONG = loadIClass("Ljava/lang/Long;");
/*  91 */       this.FLOAT = loadIClass("Ljava/lang/Float;");
/*  92 */       this.DOUBLE = loadIClass("Ljava/lang/Double;");
/*     */     } catch (ClassNotFoundException e) {
/*  94 */       throw new JaninoRuntimeException("Cannot load simple types");
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final IClass loadIClass(String fieldDescriptor)
/*     */     throws ClassNotFoundException
/*     */   {
/* 107 */     if (Descriptor.isPrimitive(fieldDescriptor)) {
/* 108 */       return fieldDescriptor.equals("Z") ? IClass.BOOLEAN : fieldDescriptor.equals("S") ? IClass.SHORT : fieldDescriptor.equals("J") ? IClass.LONG : fieldDescriptor.equals("I") ? IClass.INT : fieldDescriptor.equals("F") ? IClass.FLOAT : fieldDescriptor.equals("D") ? IClass.DOUBLE : fieldDescriptor.equals("C") ? IClass.CHAR : fieldDescriptor.equals("B") ? IClass.BYTE : fieldDescriptor.equals("V") ? IClass.VOID : null;
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 123 */     if (this.optionalParentIClassLoader != null) {
/* 124 */       IClass res = this.optionalParentIClassLoader.loadIClass(fieldDescriptor);
/* 125 */       if (res != null) { return res;
/*     */       }
/*     */     }
/*     */     
/*     */     IClass result;
/*     */     
/* 131 */     synchronized (this)
/*     */     {
/*     */ 
/* 134 */       if (this.unloadableIClasses.contains(fieldDescriptor)) { return null;
/*     */       }
/*     */       
/* 137 */       result = (IClass)this.loadedIClasses.get(fieldDescriptor);
/* 138 */       if (result != null) { return result;
/*     */       }
/*     */       
/* 141 */       if (Descriptor.isArrayReference(fieldDescriptor))
/*     */       {
/*     */ 
/* 144 */         IClass componentIClass = loadIClass(Descriptor.getComponentDescriptor(fieldDescriptor));
/*     */         
/*     */ 
/* 147 */         if (componentIClass == null) { return null;
/*     */         }
/*     */         
/* 150 */         IClass arrayIClass = componentIClass.getArrayIClass(this.OBJECT);
/* 151 */         this.loadedIClasses.put(fieldDescriptor, arrayIClass);
/* 152 */         return arrayIClass;
/*     */       }
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 158 */       result = findIClass(fieldDescriptor);
/* 159 */       if (result == null) {
/* 160 */         this.unloadableIClasses.add(fieldDescriptor);
/* 161 */         return null;
/*     */       }
/*     */     }
/*     */     
/* 165 */     if (!result.getDescriptor().equalsIgnoreCase(fieldDescriptor)) {
/* 166 */       throw new JaninoRuntimeException("\"findIClass()\" returned \"" + result.getDescriptor() + "\" instead of \"" + fieldDescriptor + "\"");
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 177 */     return result;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected abstract IClass findIClass(String paramString)
/*     */     throws ClassNotFoundException;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected final void defineIClass(IClass iClass)
/*     */   {
/* 221 */     String descriptor = iClass.getDescriptor();
/*     */     
/*     */ 
/* 224 */     IClass loadedIClass = (IClass)this.loadedIClasses.get(descriptor);
/* 225 */     if (loadedIClass != null) {
/* 226 */       if (loadedIClass == iClass) return;
/* 227 */       throw new JaninoRuntimeException("Non-identical definition of IClass \"" + descriptor + "\"");
/*     */     }
/*     */     
/*     */ 
/* 231 */     this.loadedIClasses.put(descriptor, iClass);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static IClassLoader createJavacLikePathIClassLoader(File[] optionalBootClassPath, File[] optionalExtDirs, File[] classPath)
/*     */   {
/* 250 */     ResourceFinder bootClassPathResourceFinder = new PathResourceFinder(optionalBootClassPath == null ? PathResourceFinder.parsePath(System.getProperty("sun.boot.class.path")) : optionalBootClassPath);
/*     */     
/*     */ 
/*     */ 
/*     */ 
/* 255 */     ResourceFinder extensionDirectoriesResourceFinder = new JarDirectoriesResourceFinder(optionalExtDirs == null ? PathResourceFinder.parsePath(System.getProperty("java.ext.dirs")) : optionalExtDirs);
/*     */     
/*     */ 
/*     */ 
/*     */ 
/* 260 */     ResourceFinder classPathResourceFinder = new PathResourceFinder(classPath);
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 277 */     IClassLoader icl = new ResourceFinderIClassLoader(bootClassPathResourceFinder, null);
/* 278 */     icl = new ResourceFinderIClassLoader(extensionDirectoriesResourceFinder, icl);
/* 279 */     icl = new ResourceFinderIClassLoader(classPathResourceFinder, icl);
/* 280 */     return icl;
/*     */   }
/*     */   
/*     */ 
/* 284 */   private final Map loadedIClasses = new HashMap();
/* 285 */   private final Set unloadableIClasses = new HashSet();
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\janino\IClassLoader.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       0.7.1
 */