/*     */ package org.xerial.snappy;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStream;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SnappyOutputStream
/*     */   extends OutputStream
/*     */ {
/*     */   static final int DEFAULT_BLOCK_SIZE = 32768;
/*     */   protected final OutputStream out;
/*     */   private final int blockSize;
/*  61 */   private int cursor = 0;
/*     */   protected byte[] uncompressed;
/*     */   protected byte[] compressed;
/*     */   
/*     */   public SnappyOutputStream(OutputStream out) throws IOException {
/*  66 */     this(out, 32768);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public SnappyOutputStream(OutputStream out, int blockSize)
/*     */     throws IOException
/*     */   {
/*  76 */     this.out = out;
/*  77 */     this.blockSize = blockSize;
/*  78 */     this.uncompressed = new byte[blockSize];
/*  79 */     this.compressed = new byte[Snappy.maxCompressedLength(blockSize)];
/*  80 */     writeHeader();
/*     */   }
/*     */   
/*     */   protected void writeHeader() throws IOException {
/*  84 */     SnappyCodec.currentHeader().writeHeader(this.out);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(byte[] b, int off, int len)
/*     */     throws IOException
/*     */   {
/*  99 */     rawWrite(b, off, len);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(long[] d, int off, int len)
/*     */     throws IOException
/*     */   {
/* 114 */     rawWrite(d, off * 8, len * 8);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(double[] f, int off, int len)
/*     */     throws IOException
/*     */   {
/* 129 */     rawWrite(f, off * 8, len * 8);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(float[] f, int off, int len)
/*     */     throws IOException
/*     */   {
/* 144 */     rawWrite(f, off * 4, len * 4);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(int[] f, int off, int len)
/*     */     throws IOException
/*     */   {
/* 159 */     rawWrite(f, off * 4, len * 4);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(short[] f, int off, int len)
/*     */     throws IOException
/*     */   {
/* 174 */     rawWrite(f, off * 2, len * 2);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(long[] d)
/*     */     throws IOException
/*     */   {
/* 184 */     write(d, 0, d.length);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(double[] f)
/*     */     throws IOException
/*     */   {
/* 194 */     write(f, 0, f.length);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(float[] f)
/*     */     throws IOException
/*     */   {
/* 204 */     write(f, 0, f.length);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(int[] f)
/*     */     throws IOException
/*     */   {
/* 214 */     write(f, 0, f.length);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(short[] f)
/*     */     throws IOException
/*     */   {
/* 224 */     write(f, 0, f.length);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void rawWrite(Object array, int byteOffset, int byteLength)
/*     */     throws IOException
/*     */   {
/* 237 */     for (int readBytes = 0; readBytes < byteLength;) {
/* 238 */       int copyLen = Math.min(this.uncompressed.length - this.cursor, byteLength - readBytes);
/* 239 */       Snappy.arrayCopy(array, byteOffset + readBytes, copyLen, this.uncompressed, this.cursor);
/* 240 */       readBytes += copyLen;
/* 241 */       this.cursor += copyLen;
/*     */       
/* 243 */       if (this.cursor >= this.uncompressed.length) {
/* 244 */         dump();
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void write(int b)
/*     */     throws IOException
/*     */   {
/* 260 */     if (this.cursor >= this.uncompressed.length) {
/* 261 */       dump();
/*     */     }
/* 263 */     this.uncompressed[(this.cursor++)] = ((byte)b);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void flush()
/*     */     throws IOException
/*     */   {
/* 271 */     dump();
/* 272 */     this.out.flush();
/*     */   }
/*     */   
/*     */   static void writeInt(OutputStream out, int value) throws IOException {
/* 276 */     out.write(value >> 24 & 0xFF);
/* 277 */     out.write(value >> 16 & 0xFF);
/* 278 */     out.write(value >> 8 & 0xFF);
/* 279 */     out.write(value >> 0 & 0xFF);
/*     */   }
/*     */   
/*     */   static int readInt(byte[] buffer, int pos) {
/* 283 */     int b1 = (buffer[pos] & 0xFF) << 24;
/* 284 */     int b2 = (buffer[(pos + 1)] & 0xFF) << 16;
/* 285 */     int b3 = (buffer[(pos + 2)] & 0xFF) << 8;
/* 286 */     int b4 = buffer[(pos + 3)] & 0xFF;
/* 287 */     return b1 | b2 | b3 | b4;
/*     */   }
/*     */   
/*     */   protected void dump() throws IOException {
/* 291 */     if (this.cursor <= 0) {
/* 292 */       return;
/*     */     }
/*     */     
/* 295 */     int compressedSize = Snappy.compress(this.uncompressed, 0, this.cursor, this.compressed, 0);
/* 296 */     writeInt(this.out, compressedSize);
/* 297 */     this.out.write(this.compressed, 0, compressedSize);
/* 298 */     this.cursor = 0;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void close()
/*     */     throws IOException
/*     */   {
/* 309 */     flush();
/*     */     
/* 311 */     super.close();
/* 312 */     this.out.close();
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\xerial\snappy\SnappyOutputStream.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */