package prefuse.data;

import java.util.Iterator;
import java.util.logging.Logger;
import prefuse.data.tuple.TupleManager;
import prefuse.util.PrefuseConfig;
import prefuse.util.collections.IntIterator;

public class Tree
  extends Graph
{
  private static final Logger s_logger = Logger.getLogger(Tree.class.getName());
  public static final String DEFAULT_SOURCE_KEY = PrefuseConfig.get("data.tree.sourceKey");
  public static final String DEFAULT_TARGET_KEY = PrefuseConfig.get("data.tree.targetKey");
  protected int m_root = -1;
  protected static final String CHILDINDEX = "_childIndex";
  protected static final Schema TREE_LINKS_SCHEMA = new Schema();
  
  public Tree()
  {
    super(new Table(), false);
  }
  
  public Tree(Table paramTable1, Table paramTable2)
  {
    this(paramTable1, paramTable2, DEFAULT_SOURCE_KEY, DEFAULT_TARGET_KEY);
  }
  
  public Tree(Table paramTable1, Table paramTable2, String paramString1, String paramString2)
  {
    this(paramTable1, paramTable2, DEFAULT_NODE_KEY, paramString1, paramString2);
  }
  
  public Tree(Table paramTable1, Table paramTable2, String paramString1, String paramString2, String paramString3)
  {
    super(paramTable1, paramTable2, false, paramString1, paramString2, paramString3);
    IntIterator localIntIterator = paramTable1.rows();
    while (localIntIterator.hasNext())
    {
      int i = localIntIterator.nextInt();
      if (getParent(i) < 0) {
        this.m_root = i;
      }
    }
  }
  
  void setRoot(Node paramNode)
  {
    this.m_root = paramNode.getRow();
  }
  
  protected Table createLinkTable()
  {
    Table localTable = super.createLinkTable();
    localTable.addColumns(TREE_LINKS_SCHEMA);
    return localTable;
  }
  
  protected void updateDegrees(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    super.updateDegrees(paramInt1, paramInt2, paramInt3, paramInt4);
    int i = getOutDegree(paramInt2);
    if (paramInt4 > 0)
    {
      this.m_links.setInt(paramInt3, "_childIndex", i - 1);
    }
    else if (paramInt4 < 0)
    {
      int[] arrayOfInt = (int[])this.m_links.get(paramInt2, "_outlinks");
      for (int j = 0; j < i; j++)
      {
        int k = getTargetNode(arrayOfInt[j]);
        this.m_links.setInt(k, "_childIndex", j);
      }
      this.m_links.setInt(paramInt3, "_childIndex", -1);
    }
  }
  
  public int addRootRow()
  {
    if (getNodeCount() != 0) {
      throw new IllegalStateException("Can only add a root node to an empty tree");
    }
    return this.m_root = addNodeRow();
  }
  
  public Node addRoot()
  {
    return getNode(addRootRow());
  }
  
  public int addChild(int paramInt)
  {
    int i = super.addNodeRow();
    addChildEdge(paramInt, i);
    return i;
  }
  
  public Node addChild(Node paramNode)
  {
    nodeCheck(paramNode, true);
    return getNode(addChild(paramNode.getRow()));
  }
  
  public int addChildEdge(int paramInt1, int paramInt2)
  {
    return super.addEdge(paramInt1, paramInt2);
  }
  
  public Edge addChildEdge(Node paramNode1, Node paramNode2)
  {
    nodeCheck(paramNode1, true);
    nodeCheck(paramNode2, true);
    return getEdge(addChildEdge(paramNode1.getRow(), paramNode2.getRow()));
  }
  
  public boolean removeChildEdge(int paramInt)
  {
    return removeChild(getTargetNode(paramInt));
  }
  
  public boolean removeChildEdge(Edge paramEdge)
  {
    edgeCheck(paramEdge, true);
    return removeChild(getTargetNode(paramEdge.getRow()));
  }
  
  public boolean removeChild(int paramInt)
  {
    while (getChildCount(paramInt) > 0) {
      removeChild(getLastChildRow(paramInt));
    }
    return removeNode(paramInt);
  }
  
  public boolean removeChild(Node paramNode)
  {
    nodeCheck(paramNode, true);
    return removeChild(paramNode.getRow());
  }
  
  public int getRootRow()
  {
    return this.m_root;
  }
  
  public Node getRoot()
  {
    return (Node)this.m_nodeTuples.getTuple(this.m_root);
  }
  
  public int getChildRow(int paramInt1, int paramInt2)
  {
    int i = getChildCount(paramInt1);
    if ((paramInt2 < 0) || (paramInt2 >= i)) {
      return -1;
    }
    int[] arrayOfInt = (int[])this.m_links.get(paramInt1, "_outlinks");
    return getTargetNode(arrayOfInt[paramInt2]);
  }
  
  public Node getChild(Node paramNode, int paramInt)
  {
    int i = getChildRow(paramNode.getRow(), paramInt);
    return i < 0 ? null : getNode(i);
  }
  
  public int getChildIndex(int paramInt1, int paramInt2)
  {
    if (getParent(paramInt2) != paramInt1) {
      return -1;
    }
    return this.m_links.getInt(paramInt2, "_childIndex");
  }
  
  public int getChildIndex(Node paramNode1, Node paramNode2)
  {
    return getChildIndex(paramNode1.getRow(), paramNode2.getRow());
  }
  
  public int getFirstChildRow(int paramInt)
  {
    return getChildRow(paramInt, 0);
  }
  
  public Node getFirstChild(Node paramNode)
  {
    return getChild(paramNode, 0);
  }
  
  public int getLastChildRow(int paramInt)
  {
    return getChildRow(paramInt, getChildCount(paramInt) - 1);
  }
  
  public Node getLastChild(Node paramNode)
  {
    return getChild(paramNode, paramNode.getChildCount() - 1);
  }
  
  public int getPreviousSiblingRow(int paramInt)
  {
    int i = getParent(paramInt);
    if (i < 0) {
      return -1;
    }
    int[] arrayOfInt = (int[])this.m_links.get(i, "_outlinks");
    int j = this.m_links.getInt(paramInt, "_childIndex");
    return j <= 0 ? -1 : getTargetNode(arrayOfInt[(j - 1)]);
  }
  
  public Node getPreviousSibling(Node paramNode)
  {
    int i = getPreviousSiblingRow(paramNode.getRow());
    return i < 0 ? null : getNode(i);
  }
  
  public int getNextSiblingRow(int paramInt)
  {
    int i = getParent(paramInt);
    if (i < 0) {
      return -1;
    }
    int[] arrayOfInt = (int[])this.m_links.get(i, "_outlinks");
    int j = this.m_links.getInt(paramInt, "_childIndex");
    int k = getChildCount(i) - 1;
    return (j < 0) || (j >= k) ? -1 : getTargetNode(arrayOfInt[(j + 1)]);
  }
  
  public Node getNextSibling(Node paramNode)
  {
    int i = getNextSiblingRow(paramNode.getRow());
    return i < 0 ? null : getNode(i);
  }
  
  public int getDepth(int paramInt)
  {
    if (!getNodeTable().isValidRow(paramInt)) {
      return -1;
    }
    int i = 0;
    for (int j = paramInt; j != this.m_root; j = getParent(j)) {
      i++;
    }
    return i;
  }
  
  public int getChildCount(int paramInt)
  {
    return getOutDegree(paramInt);
  }
  
  public int getParentEdge(int paramInt)
  {
    if (getInDegree(paramInt) > 0)
    {
      int[] arrayOfInt = (int[])this.m_links.get(paramInt, "_inlinks");
      return arrayOfInt[0];
    }
    return -1;
  }
  
  public Edge getParentEdge(Node paramNode)
  {
    nodeCheck(paramNode, true);
    int i = getParentEdge(paramNode.getRow());
    return i < 0 ? null : getEdge(i);
  }
  
  public int getParent(int paramInt)
  {
    int i = getParentEdge(paramInt);
    return i < 0 ? -1 : getSourceNode(i);
  }
  
  public Node getParent(Node paramNode)
  {
    int i = getParent(paramNode.getRow());
    return i < 0 ? null : getNode(i);
  }
  
  public IntIterator childEdgeRows(int paramInt)
  {
    return super.outEdgeRows(paramInt);
  }
  
  public Iterator childEdges(Node paramNode)
  {
    return super.outEdges(paramNode);
  }
  
  public Iterator children(Node paramNode)
  {
    return super.outNeighbors(paramNode);
  }
  
  public boolean isValidTree()
  {
    int i = getNodeCount();
    int j = getEdgeCount();
    if (i != j + 1)
    {
      s_logger.warning("Node/edge counts incorrect.");
      return false;
    }
    int k = getRootRow();
    IntIterator localIntIterator = getNodeTable().rows();
    while (localIntIterator.hasNext())
    {
      int m = localIntIterator.nextInt();
      int n = getInDegree(m);
      if ((m == k) && (n > 0))
      {
        s_logger.warning("Root node has a parent.");
        return false;
      }
      if (n > 1)
      {
        s_logger.warning("Node " + m + " has multiple parents.");
        return false;
      }
    }
    int[] arrayOfInt = { 0, j };
    isValidHelper(getRootRow(), arrayOfInt);
    if (arrayOfInt[0] > j)
    {
      s_logger.warning("The tree has non-tree edges in it.");
      return false;
    }
    if (arrayOfInt[0] < j)
    {
      s_logger.warning("Not all of the tree was visited. Only " + arrayOfInt[0] + "/" + j + " edges encountered");
      return false;
    }
    return true;
  }
  
  private void isValidHelper(int paramInt, int[] paramArrayOfInt)
  {
    IntIterator localIntIterator = childEdgeRows(paramInt);
    int i = 0;
    while (localIntIterator.hasNext())
    {
      int j = localIntIterator.nextInt();
      i++;
      paramArrayOfInt[0] += 1;
      int k = getAdjacentNode(j, paramInt);
      isValidHelper(k, paramArrayOfInt);
      if (paramArrayOfInt[0] > paramArrayOfInt[1]) {
        return;
      }
    }
  }
  
  public Tree getSpanningTree()
  {
    return this.m_spanning == null ? this : this.m_spanning;
  }
  
  public Tree getSpanningTree(Node paramNode)
  {
    nodeCheck(paramNode, true);
    if (this.m_spanning == null)
    {
      if (this.m_root == paramNode.getRow()) {
        return this;
      }
      this.m_spanning = new SpanningTree(this, paramNode);
    }
    else if (this.m_spanning.getRoot() != paramNode)
    {
      this.m_spanning.buildSpanningTree(paramNode);
    }
    return this.m_spanning;
  }
  
  static
  {
    TREE_LINKS_SCHEMA.addColumn("_childIndex", Integer.TYPE, new Integer(-1));
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\Tree.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */