package prefuse.data.expression;

import prefuse.data.Schema;
import prefuse.data.Tuple;
import prefuse.util.TypeLib;

public class ArithmeticExpression
  extends BinaryExpression
{
  public static final int ADD = 0;
  public static final int SUB = 1;
  public static final int MUL = 2;
  public static final int DIV = 3;
  public static final int POW = 4;
  public static final int MOD = 5;
  private Class m_type = null;
  
  public ArithmeticExpression(int paramInt, Expression paramExpression1, Expression paramExpression2)
  {
    super(paramInt, 0, 5, paramExpression1, paramExpression2);
  }
  
  public Class getType(Schema paramSchema)
  {
    if (this.m_type == null)
    {
      Class localClass1 = this.m_left.getType(paramSchema);
      Class localClass2 = this.m_right.getType(paramSchema);
      this.m_type = TypeLib.getNumericType(localClass1, localClass2);
    }
    return this.m_type;
  }
  
  public Object get(Tuple paramTuple)
  {
    Class localClass = getType(paramTuple.getSchema());
    if (Integer.TYPE == localClass) {
      return new Integer(getInt(paramTuple));
    }
    if (Long.TYPE == localClass) {
      return new Long(getInt(paramTuple));
    }
    if (Float.TYPE == localClass) {
      return new Float(getFloat(paramTuple));
    }
    if (Double.TYPE == localClass) {
      return new Double(getDouble(paramTuple));
    }
    throw new IllegalStateException();
  }
  
  public int getInt(Tuple paramTuple)
  {
    int i = this.m_left.getInt(paramTuple);
    int j = this.m_right.getInt(paramTuple);
    switch (this.m_op)
    {
    case 0: 
      return i + j;
    case 1: 
      return i - j;
    case 2: 
      return i * j;
    case 3: 
      return i / j;
    case 4: 
      return (int)Math.pow(i, j);
    case 5: 
      return i % j;
    }
    throw new IllegalStateException("Unknown operation type.");
  }
  
  public long getLong(Tuple paramTuple)
  {
    long l1 = this.m_left.getLong(paramTuple);
    long l2 = this.m_right.getLong(paramTuple);
    switch (this.m_op)
    {
    case 0: 
      return l1 + l2;
    case 1: 
      return l1 - l2;
    case 2: 
      return l1 * l2;
    case 3: 
      return l1 / l2;
    case 4: 
      return Math.pow(l1, l2);
    case 5: 
      return l1 % l2;
    }
    throw new IllegalStateException("Unknown operation type.");
  }
  
  public float getFloat(Tuple paramTuple)
  {
    float f1 = this.m_left.getFloat(paramTuple);
    float f2 = this.m_right.getFloat(paramTuple);
    switch (this.m_op)
    {
    case 0: 
      return f1 + f2;
    case 1: 
      return f1 - f2;
    case 2: 
      return f1 * f2;
    case 3: 
      return f1 / f2;
    case 4: 
      return (float)Math.pow(f1, f2);
    case 5: 
      return (float)Math.IEEEremainder(f1, f2);
    }
    throw new IllegalStateException("Unknown operation type.");
  }
  
  public double getDouble(Tuple paramTuple)
  {
    double d1 = this.m_left.getDouble(paramTuple);
    double d2 = this.m_right.getDouble(paramTuple);
    switch (this.m_op)
    {
    case 0: 
      return d1 + d2;
    case 1: 
      return d1 - d2;
    case 2: 
      return d1 * d2;
    case 3: 
      return d1 / d2;
    case 4: 
      return Math.pow(d1, d2);
    case 5: 
      return Math.IEEEremainder(d1, d2);
    }
    throw new IllegalStateException("Unknown operation type.");
  }
  
  public String toString()
  {
    char c = '?';
    switch (this.m_op)
    {
    case 0: 
      c = '+';
      break;
    case 1: 
      c = '-';
      break;
    case 2: 
      c = '*';
      break;
    case 3: 
      c = '/';
      break;
    case 4: 
      c = '^';
      break;
    case 5: 
      c = '%';
    }
    return '(' + this.m_left.toString() + ' ' + c + ' ' + this.m_right.toString() + ')';
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\expression\ArithmeticExpression.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */